from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.rule_severity_level import RuleSeverityLevel
from ..types import UNSET, Unset

T = TypeVar("T", bound="RunChecksResult")


@_attrs_define
class RunChecksResult:
    """Returns the result (highest data quality check severity and the finished checks count) for the checks that were
    recently executed.

        Attributes:
            highest_severity (Union[Unset, RuleSeverityLevel]):
            executed_checks (Union[Unset, int]): The total count of all executed checks.
            valid_results (Union[Unset, int]): The total count of all checks that finished successfully (with no data
                quality issues).
            warnings (Union[Unset, int]): The total count of all invalid data quality checks that finished raising a
                warning.
            errors (Union[Unset, int]): The total count of all invalid data quality checks that finished raising an error.
            fatals (Union[Unset, int]): The total count of all invalid data quality checks that finished raising a fatal
                error.
            execution_errors (Union[Unset, int]): The total number of checks that failed to execute due to some execution
                errors.
    """

    highest_severity: Union[Unset, RuleSeverityLevel] = UNSET
    executed_checks: Union[Unset, int] = UNSET
    valid_results: Union[Unset, int] = UNSET
    warnings: Union[Unset, int] = UNSET
    errors: Union[Unset, int] = UNSET
    fatals: Union[Unset, int] = UNSET
    execution_errors: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        highest_severity: Union[Unset, str] = UNSET
        if not isinstance(self.highest_severity, Unset):
            highest_severity = self.highest_severity.value

        executed_checks = self.executed_checks
        valid_results = self.valid_results
        warnings = self.warnings
        errors = self.errors
        fatals = self.fatals
        execution_errors = self.execution_errors

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if highest_severity is not UNSET:
            field_dict["highest_severity"] = highest_severity
        if executed_checks is not UNSET:
            field_dict["executed_checks"] = executed_checks
        if valid_results is not UNSET:
            field_dict["valid_results"] = valid_results
        if warnings is not UNSET:
            field_dict["warnings"] = warnings
        if errors is not UNSET:
            field_dict["errors"] = errors
        if fatals is not UNSET:
            field_dict["fatals"] = fatals
        if execution_errors is not UNSET:
            field_dict["execution_errors"] = execution_errors

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _highest_severity = d.pop("highest_severity", UNSET)
        highest_severity: Union[Unset, RuleSeverityLevel]
        if isinstance(_highest_severity, Unset):
            highest_severity = UNSET
        else:
            highest_severity = RuleSeverityLevel(_highest_severity)

        executed_checks = d.pop("executed_checks", UNSET)

        valid_results = d.pop("valid_results", UNSET)

        warnings = d.pop("warnings", UNSET)

        errors = d.pop("errors", UNSET)

        fatals = d.pop("fatals", UNSET)

        execution_errors = d.pop("execution_errors", UNSET)

        run_checks_result = cls(
            highest_severity=highest_severity,
            executed_checks=executed_checks,
            valid_results=valid_results,
            warnings=warnings,
            errors=errors,
            fatals=fatals,
            execution_errors=execution_errors,
        )

        run_checks_result.additional_properties = d
        return run_checks_result

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_nulls_not_nulls_count_statistics_collector_spec import (
        ColumnNullsNotNullsCountStatisticsCollectorSpec,
    )
    from ..models.column_nulls_not_nulls_percent_statistics_collector_spec import (
        ColumnNullsNotNullsPercentStatisticsCollectorSpec,
    )
    from ..models.column_nulls_nulls_count_statistics_collector_spec import (
        ColumnNullsNullsCountStatisticsCollectorSpec,
    )
    from ..models.column_nulls_nulls_percent_statistics_collector_spec import (
        ColumnNullsNullsPercentStatisticsCollectorSpec,
    )


T = TypeVar("T", bound="ColumnNullsStatisticsCollectorsSpec")


@_attrs_define
class ColumnNullsStatisticsCollectorsSpec:
    """
    Attributes:
        nulls_count (Union[Unset, ColumnNullsNullsCountStatisticsCollectorSpec]):
        nulls_percent (Union[Unset, ColumnNullsNullsPercentStatisticsCollectorSpec]):
        not_nulls_count (Union[Unset, ColumnNullsNotNullsCountStatisticsCollectorSpec]):
        not_nulls_percent (Union[Unset, ColumnNullsNotNullsPercentStatisticsCollectorSpec]):
    """

    nulls_count: Union[Unset, "ColumnNullsNullsCountStatisticsCollectorSpec"] = UNSET
    nulls_percent: Union[Unset, "ColumnNullsNullsPercentStatisticsCollectorSpec"] = (
        UNSET
    )
    not_nulls_count: Union[Unset, "ColumnNullsNotNullsCountStatisticsCollectorSpec"] = (
        UNSET
    )
    not_nulls_percent: Union[
        Unset, "ColumnNullsNotNullsPercentStatisticsCollectorSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        nulls_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.nulls_count, Unset):
            nulls_count = self.nulls_count.to_dict()

        nulls_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.nulls_percent, Unset):
            nulls_percent = self.nulls_percent.to_dict()

        not_nulls_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.not_nulls_count, Unset):
            not_nulls_count = self.not_nulls_count.to_dict()

        not_nulls_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.not_nulls_percent, Unset):
            not_nulls_percent = self.not_nulls_percent.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if nulls_count is not UNSET:
            field_dict["nulls_count"] = nulls_count
        if nulls_percent is not UNSET:
            field_dict["nulls_percent"] = nulls_percent
        if not_nulls_count is not UNSET:
            field_dict["not_nulls_count"] = not_nulls_count
        if not_nulls_percent is not UNSET:
            field_dict["not_nulls_percent"] = not_nulls_percent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_nulls_not_nulls_count_statistics_collector_spec import (
            ColumnNullsNotNullsCountStatisticsCollectorSpec,
        )
        from ..models.column_nulls_not_nulls_percent_statistics_collector_spec import (
            ColumnNullsNotNullsPercentStatisticsCollectorSpec,
        )
        from ..models.column_nulls_nulls_count_statistics_collector_spec import (
            ColumnNullsNullsCountStatisticsCollectorSpec,
        )
        from ..models.column_nulls_nulls_percent_statistics_collector_spec import (
            ColumnNullsNullsPercentStatisticsCollectorSpec,
        )

        d = src_dict.copy()
        _nulls_count = d.pop("nulls_count", UNSET)
        nulls_count: Union[Unset, ColumnNullsNullsCountStatisticsCollectorSpec]
        if isinstance(_nulls_count, Unset):
            nulls_count = UNSET
        else:
            nulls_count = ColumnNullsNullsCountStatisticsCollectorSpec.from_dict(
                _nulls_count
            )

        _nulls_percent = d.pop("nulls_percent", UNSET)
        nulls_percent: Union[Unset, ColumnNullsNullsPercentStatisticsCollectorSpec]
        if isinstance(_nulls_percent, Unset):
            nulls_percent = UNSET
        else:
            nulls_percent = ColumnNullsNullsPercentStatisticsCollectorSpec.from_dict(
                _nulls_percent
            )

        _not_nulls_count = d.pop("not_nulls_count", UNSET)
        not_nulls_count: Union[Unset, ColumnNullsNotNullsCountStatisticsCollectorSpec]
        if isinstance(_not_nulls_count, Unset):
            not_nulls_count = UNSET
        else:
            not_nulls_count = ColumnNullsNotNullsCountStatisticsCollectorSpec.from_dict(
                _not_nulls_count
            )

        _not_nulls_percent = d.pop("not_nulls_percent", UNSET)
        not_nulls_percent: Union[
            Unset, ColumnNullsNotNullsPercentStatisticsCollectorSpec
        ]
        if isinstance(_not_nulls_percent, Unset):
            not_nulls_percent = UNSET
        else:
            not_nulls_percent = (
                ColumnNullsNotNullsPercentStatisticsCollectorSpec.from_dict(
                    _not_nulls_percent
                )
            )

        column_nulls_statistics_collectors_spec = cls(
            nulls_count=nulls_count,
            nulls_percent=nulls_percent,
            not_nulls_count=not_nulls_count,
            not_nulls_percent=not_nulls_percent,
        )

        column_nulls_statistics_collectors_spec.additional_properties = d
        return column_nulls_statistics_collectors_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.credential_type import CredentialType
from ..types import UNSET, Unset

T = TypeVar("T", bound="SharedCredentialListModel")


@_attrs_define
class SharedCredentialListModel:
    """Shared credentials list model with the basic information about the credential.

    Attributes:
        credential_name (Union[Unset, str]): Credential name. It is the name of a file in the .credentials/ folder
            inside the DQOps user's home folder.
        type (Union[Unset, CredentialType]):
        can_edit (Union[Unset, bool]): Boolean flag that decides if the current user can update or delete the shared
            credential file.
        can_access_credential (Union[Unset, bool]): Boolean flag that decides if the current user see or download the
            credential file.
    """

    credential_name: Union[Unset, str] = UNSET
    type: Union[Unset, CredentialType] = UNSET
    can_edit: Union[Unset, bool] = UNSET
    can_access_credential: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        credential_name = self.credential_name
        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        can_edit = self.can_edit
        can_access_credential = self.can_access_credential

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if credential_name is not UNSET:
            field_dict["credential_name"] = credential_name
        if type is not UNSET:
            field_dict["type"] = type
        if can_edit is not UNSET:
            field_dict["can_edit"] = can_edit
        if can_access_credential is not UNSET:
            field_dict["can_access_credential"] = can_access_credential

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        credential_name = d.pop("credential_name", UNSET)

        _type = d.pop("type", UNSET)
        type: Union[Unset, CredentialType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = CredentialType(_type)

        can_edit = d.pop("can_edit", UNSET)

        can_access_credential = d.pop("can_access_credential", UNSET)

        shared_credential_list_model = cls(
            credential_name=credential_name,
            type=type,
            can_edit=can_edit,
            can_access_credential=can_access_credential,
        )

        shared_credential_list_model.additional_properties = d
        return shared_credential_list_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_data_ingestion_delay_check_spec import (
        TableDataIngestionDelayCheckSpec,
    )
    from ..models.table_partition_reload_lag_check_spec import (
        TablePartitionReloadLagCheckSpec,
    )
    from ..models.table_timeliness_daily_partitioned_checks_spec_custom_checks import (
        TableTimelinessDailyPartitionedChecksSpecCustomChecks,
    )


T = TypeVar("T", bound="TableTimelinessDailyPartitionedChecksSpec")


@_attrs_define
class TableTimelinessDailyPartitionedChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, TableTimelinessDailyPartitionedChecksSpecCustomChecks]): Dictionary of additional
            custom checks within this category. The keys are check names defined in the definition section. The sensor
            parameters and rules should match the type of the configured sensor and rule for the custom check.
        daily_partition_data_ingestion_delay (Union[Unset, TableDataIngestionDelayCheckSpec]):
        daily_partition_reload_lag (Union[Unset, TablePartitionReloadLagCheckSpec]):
    """

    custom_checks: Union[
        Unset, "TableTimelinessDailyPartitionedChecksSpecCustomChecks"
    ] = UNSET
    daily_partition_data_ingestion_delay: Union[
        Unset, "TableDataIngestionDelayCheckSpec"
    ] = UNSET
    daily_partition_reload_lag: Union[Unset, "TablePartitionReloadLagCheckSpec"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        daily_partition_data_ingestion_delay: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_partition_data_ingestion_delay, Unset):
            daily_partition_data_ingestion_delay = (
                self.daily_partition_data_ingestion_delay.to_dict()
            )

        daily_partition_reload_lag: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_partition_reload_lag, Unset):
            daily_partition_reload_lag = self.daily_partition_reload_lag.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if daily_partition_data_ingestion_delay is not UNSET:
            field_dict["daily_partition_data_ingestion_delay"] = (
                daily_partition_data_ingestion_delay
            )
        if daily_partition_reload_lag is not UNSET:
            field_dict["daily_partition_reload_lag"] = daily_partition_reload_lag

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_data_ingestion_delay_check_spec import (
            TableDataIngestionDelayCheckSpec,
        )
        from ..models.table_partition_reload_lag_check_spec import (
            TablePartitionReloadLagCheckSpec,
        )
        from ..models.table_timeliness_daily_partitioned_checks_spec_custom_checks import (
            TableTimelinessDailyPartitionedChecksSpecCustomChecks,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[
            Unset, TableTimelinessDailyPartitionedChecksSpecCustomChecks
        ]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = (
                TableTimelinessDailyPartitionedChecksSpecCustomChecks.from_dict(
                    _custom_checks
                )
            )

        _daily_partition_data_ingestion_delay = d.pop(
            "daily_partition_data_ingestion_delay", UNSET
        )
        daily_partition_data_ingestion_delay: Union[
            Unset, TableDataIngestionDelayCheckSpec
        ]
        if isinstance(_daily_partition_data_ingestion_delay, Unset):
            daily_partition_data_ingestion_delay = UNSET
        else:
            daily_partition_data_ingestion_delay = (
                TableDataIngestionDelayCheckSpec.from_dict(
                    _daily_partition_data_ingestion_delay
                )
            )

        _daily_partition_reload_lag = d.pop("daily_partition_reload_lag", UNSET)
        daily_partition_reload_lag: Union[Unset, TablePartitionReloadLagCheckSpec]
        if isinstance(_daily_partition_reload_lag, Unset):
            daily_partition_reload_lag = UNSET
        else:
            daily_partition_reload_lag = TablePartitionReloadLagCheckSpec.from_dict(
                _daily_partition_reload_lag
            )

        table_timeliness_daily_partitioned_checks_spec = cls(
            custom_checks=custom_checks,
            daily_partition_data_ingestion_delay=daily_partition_data_ingestion_delay,
            daily_partition_reload_lag=daily_partition_reload_lag,
        )

        table_timeliness_daily_partitioned_checks_spec.additional_properties = d
        return table_timeliness_daily_partitioned_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_row_count_anomaly_differencing_check_spec import (
        TableRowCountAnomalyDifferencingCheckSpec,
    )
    from ..models.table_row_count_change_1_day_check_spec import (
        TableRowCountChange1DayCheckSpec,
    )
    from ..models.table_row_count_change_7_days_check_spec import (
        TableRowCountChange7DaysCheckSpec,
    )
    from ..models.table_row_count_change_30_days_check_spec import (
        TableRowCountChange30DaysCheckSpec,
    )
    from ..models.table_row_count_change_check_spec import TableRowCountChangeCheckSpec
    from ..models.table_row_count_check_spec import TableRowCountCheckSpec
    from ..models.table_volume_profiling_checks_spec_custom_checks import (
        TableVolumeProfilingChecksSpecCustomChecks,
    )


T = TypeVar("T", bound="TableVolumeProfilingChecksSpec")


@_attrs_define
class TableVolumeProfilingChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, TableVolumeProfilingChecksSpecCustomChecks]): Dictionary of additional custom checks
            within this category. The keys are check names defined in the definition section. The sensor parameters and
            rules should match the type of the configured sensor and rule for the custom check.
        profile_row_count (Union[Unset, TableRowCountCheckSpec]):
        profile_row_count_anomaly (Union[Unset, TableRowCountAnomalyDifferencingCheckSpec]):
        profile_row_count_change (Union[Unset, TableRowCountChangeCheckSpec]):
        profile_row_count_change_1_day (Union[Unset, TableRowCountChange1DayCheckSpec]):
        profile_row_count_change_7_days (Union[Unset, TableRowCountChange7DaysCheckSpec]):
        profile_row_count_change_30_days (Union[Unset, TableRowCountChange30DaysCheckSpec]):
    """

    custom_checks: Union[Unset, "TableVolumeProfilingChecksSpecCustomChecks"] = UNSET
    profile_row_count: Union[Unset, "TableRowCountCheckSpec"] = UNSET
    profile_row_count_anomaly: Union[
        Unset, "TableRowCountAnomalyDifferencingCheckSpec"
    ] = UNSET
    profile_row_count_change: Union[Unset, "TableRowCountChangeCheckSpec"] = UNSET
    profile_row_count_change_1_day: Union[Unset, "TableRowCountChange1DayCheckSpec"] = (
        UNSET
    )
    profile_row_count_change_7_days: Union[
        Unset, "TableRowCountChange7DaysCheckSpec"
    ] = UNSET
    profile_row_count_change_30_days: Union[
        Unset, "TableRowCountChange30DaysCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        profile_row_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_row_count, Unset):
            profile_row_count = self.profile_row_count.to_dict()

        profile_row_count_anomaly: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_row_count_anomaly, Unset):
            profile_row_count_anomaly = self.profile_row_count_anomaly.to_dict()

        profile_row_count_change: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_row_count_change, Unset):
            profile_row_count_change = self.profile_row_count_change.to_dict()

        profile_row_count_change_1_day: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_row_count_change_1_day, Unset):
            profile_row_count_change_1_day = (
                self.profile_row_count_change_1_day.to_dict()
            )

        profile_row_count_change_7_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_row_count_change_7_days, Unset):
            profile_row_count_change_7_days = (
                self.profile_row_count_change_7_days.to_dict()
            )

        profile_row_count_change_30_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_row_count_change_30_days, Unset):
            profile_row_count_change_30_days = (
                self.profile_row_count_change_30_days.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if profile_row_count is not UNSET:
            field_dict["profile_row_count"] = profile_row_count
        if profile_row_count_anomaly is not UNSET:
            field_dict["profile_row_count_anomaly"] = profile_row_count_anomaly
        if profile_row_count_change is not UNSET:
            field_dict["profile_row_count_change"] = profile_row_count_change
        if profile_row_count_change_1_day is not UNSET:
            field_dict["profile_row_count_change_1_day"] = (
                profile_row_count_change_1_day
            )
        if profile_row_count_change_7_days is not UNSET:
            field_dict["profile_row_count_change_7_days"] = (
                profile_row_count_change_7_days
            )
        if profile_row_count_change_30_days is not UNSET:
            field_dict["profile_row_count_change_30_days"] = (
                profile_row_count_change_30_days
            )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_row_count_anomaly_differencing_check_spec import (
            TableRowCountAnomalyDifferencingCheckSpec,
        )
        from ..models.table_row_count_change_1_day_check_spec import (
            TableRowCountChange1DayCheckSpec,
        )
        from ..models.table_row_count_change_7_days_check_spec import (
            TableRowCountChange7DaysCheckSpec,
        )
        from ..models.table_row_count_change_30_days_check_spec import (
            TableRowCountChange30DaysCheckSpec,
        )
        from ..models.table_row_count_change_check_spec import (
            TableRowCountChangeCheckSpec,
        )
        from ..models.table_row_count_check_spec import TableRowCountCheckSpec
        from ..models.table_volume_profiling_checks_spec_custom_checks import (
            TableVolumeProfilingChecksSpecCustomChecks,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[Unset, TableVolumeProfilingChecksSpecCustomChecks]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = TableVolumeProfilingChecksSpecCustomChecks.from_dict(
                _custom_checks
            )

        _profile_row_count = d.pop("profile_row_count", UNSET)
        profile_row_count: Union[Unset, TableRowCountCheckSpec]
        if isinstance(_profile_row_count, Unset):
            profile_row_count = UNSET
        else:
            profile_row_count = TableRowCountCheckSpec.from_dict(_profile_row_count)

        _profile_row_count_anomaly = d.pop("profile_row_count_anomaly", UNSET)
        profile_row_count_anomaly: Union[
            Unset, TableRowCountAnomalyDifferencingCheckSpec
        ]
        if isinstance(_profile_row_count_anomaly, Unset):
            profile_row_count_anomaly = UNSET
        else:
            profile_row_count_anomaly = (
                TableRowCountAnomalyDifferencingCheckSpec.from_dict(
                    _profile_row_count_anomaly
                )
            )

        _profile_row_count_change = d.pop("profile_row_count_change", UNSET)
        profile_row_count_change: Union[Unset, TableRowCountChangeCheckSpec]
        if isinstance(_profile_row_count_change, Unset):
            profile_row_count_change = UNSET
        else:
            profile_row_count_change = TableRowCountChangeCheckSpec.from_dict(
                _profile_row_count_change
            )

        _profile_row_count_change_1_day = d.pop("profile_row_count_change_1_day", UNSET)
        profile_row_count_change_1_day: Union[Unset, TableRowCountChange1DayCheckSpec]
        if isinstance(_profile_row_count_change_1_day, Unset):
            profile_row_count_change_1_day = UNSET
        else:
            profile_row_count_change_1_day = TableRowCountChange1DayCheckSpec.from_dict(
                _profile_row_count_change_1_day
            )

        _profile_row_count_change_7_days = d.pop(
            "profile_row_count_change_7_days", UNSET
        )
        profile_row_count_change_7_days: Union[Unset, TableRowCountChange7DaysCheckSpec]
        if isinstance(_profile_row_count_change_7_days, Unset):
            profile_row_count_change_7_days = UNSET
        else:
            profile_row_count_change_7_days = (
                TableRowCountChange7DaysCheckSpec.from_dict(
                    _profile_row_count_change_7_days
                )
            )

        _profile_row_count_change_30_days = d.pop(
            "profile_row_count_change_30_days", UNSET
        )
        profile_row_count_change_30_days: Union[
            Unset, TableRowCountChange30DaysCheckSpec
        ]
        if isinstance(_profile_row_count_change_30_days, Unset):
            profile_row_count_change_30_days = UNSET
        else:
            profile_row_count_change_30_days = (
                TableRowCountChange30DaysCheckSpec.from_dict(
                    _profile_row_count_change_30_days
                )
            )

        table_volume_profiling_checks_spec = cls(
            custom_checks=custom_checks,
            profile_row_count=profile_row_count,
            profile_row_count_anomaly=profile_row_count_anomaly,
            profile_row_count_change=profile_row_count_change,
            profile_row_count_change_1_day=profile_row_count_change_1_day,
            profile_row_count_change_7_days=profile_row_count_change_7_days,
            profile_row_count_change_30_days=profile_row_count_change_30_days,
        )

        table_volume_profiling_checks_spec.additional_properties = d
        return table_volume_profiling_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class IncidentStatus(str, Enum):
    ACKNOWLEDGED = "acknowledged"
    MUTED = "muted"
    OPEN = "open"
    RESOLVED = "resolved"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.aws_authentication_mode import AwsAuthenticationMode
from ..models.azure_authentication_mode import AzureAuthenticationMode
from ..models.duckdb_files_format_type import DuckdbFilesFormatType
from ..models.duckdb_read_mode import DuckdbReadMode
from ..models.duckdb_storage_type import DuckdbStorageType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.avro_file_format_spec import AvroFileFormatSpec
    from ..models.csv_file_format_spec import CsvFileFormatSpec
    from ..models.delta_lake_file_format_spec import DeltaLakeFileFormatSpec
    from ..models.duckdb_parameters_spec_directories import (
        DuckdbParametersSpecDirectories,
    )
    from ..models.duckdb_parameters_spec_properties import (
        DuckdbParametersSpecProperties,
    )
    from ..models.iceberg_file_format_spec import IcebergFileFormatSpec
    from ..models.json_file_format_spec import JsonFileFormatSpec
    from ..models.parquet_file_format_spec import ParquetFileFormatSpec


T = TypeVar("T", bound="DuckdbParametersSpec")


@_attrs_define
class DuckdbParametersSpec:
    """
    Attributes:
        read_mode (Union[Unset, DuckdbReadMode]):
        files_format_type (Union[Unset, DuckdbFilesFormatType]):
        database (Union[Unset, str]): DuckDB database name for in-memory read mode. The value can be in the
            ${ENVIRONMENT_VARIABLE_NAME} format to use dynamic substitution.
        properties (Union[Unset, DuckdbParametersSpecProperties]): A dictionary of custom JDBC parameters that are added
            to the JDBC connection string, a key/value dictionary.
        csv (Union[Unset, CsvFileFormatSpec]):
        json (Union[Unset, JsonFileFormatSpec]):
        parquet (Union[Unset, ParquetFileFormatSpec]):
        avro (Union[Unset, AvroFileFormatSpec]):
        iceberg (Union[Unset, IcebergFileFormatSpec]):
        delta_lake (Union[Unset, DeltaLakeFileFormatSpec]):
        directories (Union[Unset, DuckdbParametersSpecDirectories]): Virtual schema name to directory mappings. The path
            must be an absolute path.
        storage_type (Union[Unset, DuckdbStorageType]):
        aws_authentication_mode (Union[Unset, AwsAuthenticationMode]):
        azure_authentication_mode (Union[Unset, AzureAuthenticationMode]):
        user (Union[Unset, str]): DuckDB user name for a remote storage type. The value can be in the
            ${ENVIRONMENT_VARIABLE_NAME} format to use dynamic substitution.
        password (Union[Unset, str]): DuckDB password for a remote storage type. The value can be in the
            ${ENVIRONMENT_VARIABLE_NAME} format to use dynamic substitution.
        region (Union[Unset, str]): The region for the storage credentials. The value can be in the
            ${ENVIRONMENT_VARIABLE_NAME} format to use dynamic substitution.
        tenant_id (Union[Unset, str]): Azure Tenant ID used by DuckDB Secret Manager. The value can be in the
            ${ENVIRONMENT_VARIABLE_NAME} format to use dynamic substitution.
        client_id (Union[Unset, str]): Azure Client ID used by DuckDB Secret Manager. The value can be in the
            ${ENVIRONMENT_VARIABLE_NAME} format to use dynamic substitution.
        client_secret (Union[Unset, str]): Azure Client Secret used by DuckDB Secret Manager. The value can be in the
            ${ENVIRONMENT_VARIABLE_NAME} format to use dynamic substitution.
        account_name (Union[Unset, str]): Azure Storage Account Name used by DuckDB Secret Manager. The value can be in
            the ${ENVIRONMENT_VARIABLE_NAME} format to use dynamic substitution.
    """

    read_mode: Union[Unset, DuckdbReadMode] = UNSET
    files_format_type: Union[Unset, DuckdbFilesFormatType] = UNSET
    database: Union[Unset, str] = UNSET
    properties: Union[Unset, "DuckdbParametersSpecProperties"] = UNSET
    csv: Union[Unset, "CsvFileFormatSpec"] = UNSET
    json: Union[Unset, "JsonFileFormatSpec"] = UNSET
    parquet: Union[Unset, "ParquetFileFormatSpec"] = UNSET
    avro: Union[Unset, "AvroFileFormatSpec"] = UNSET
    iceberg: Union[Unset, "IcebergFileFormatSpec"] = UNSET
    delta_lake: Union[Unset, "DeltaLakeFileFormatSpec"] = UNSET
    directories: Union[Unset, "DuckdbParametersSpecDirectories"] = UNSET
    storage_type: Union[Unset, DuckdbStorageType] = UNSET
    aws_authentication_mode: Union[Unset, AwsAuthenticationMode] = UNSET
    azure_authentication_mode: Union[Unset, AzureAuthenticationMode] = UNSET
    user: Union[Unset, str] = UNSET
    password: Union[Unset, str] = UNSET
    region: Union[Unset, str] = UNSET
    tenant_id: Union[Unset, str] = UNSET
    client_id: Union[Unset, str] = UNSET
    client_secret: Union[Unset, str] = UNSET
    account_name: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        read_mode: Union[Unset, str] = UNSET
        if not isinstance(self.read_mode, Unset):
            read_mode = self.read_mode.value

        files_format_type: Union[Unset, str] = UNSET
        if not isinstance(self.files_format_type, Unset):
            files_format_type = self.files_format_type.value

        database = self.database
        properties: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.properties, Unset):
            properties = self.properties.to_dict()

        csv: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.csv, Unset):
            csv = self.csv.to_dict()

        json: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.json, Unset):
            json = self.json.to_dict()

        parquet: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.parquet, Unset):
            parquet = self.parquet.to_dict()

        avro: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.avro, Unset):
            avro = self.avro.to_dict()

        iceberg: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.iceberg, Unset):
            iceberg = self.iceberg.to_dict()

        delta_lake: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.delta_lake, Unset):
            delta_lake = self.delta_lake.to_dict()

        directories: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.directories, Unset):
            directories = self.directories.to_dict()

        storage_type: Union[Unset, str] = UNSET
        if not isinstance(self.storage_type, Unset):
            storage_type = self.storage_type.value

        aws_authentication_mode: Union[Unset, str] = UNSET
        if not isinstance(self.aws_authentication_mode, Unset):
            aws_authentication_mode = self.aws_authentication_mode.value

        azure_authentication_mode: Union[Unset, str] = UNSET
        if not isinstance(self.azure_authentication_mode, Unset):
            azure_authentication_mode = self.azure_authentication_mode.value

        user = self.user
        password = self.password
        region = self.region
        tenant_id = self.tenant_id
        client_id = self.client_id
        client_secret = self.client_secret
        account_name = self.account_name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if read_mode is not UNSET:
            field_dict["read_mode"] = read_mode
        if files_format_type is not UNSET:
            field_dict["files_format_type"] = files_format_type
        if database is not UNSET:
            field_dict["database"] = database
        if properties is not UNSET:
            field_dict["properties"] = properties
        if csv is not UNSET:
            field_dict["csv"] = csv
        if json is not UNSET:
            field_dict["json"] = json
        if parquet is not UNSET:
            field_dict["parquet"] = parquet
        if avro is not UNSET:
            field_dict["avro"] = avro
        if iceberg is not UNSET:
            field_dict["iceberg"] = iceberg
        if delta_lake is not UNSET:
            field_dict["delta_lake"] = delta_lake
        if directories is not UNSET:
            field_dict["directories"] = directories
        if storage_type is not UNSET:
            field_dict["storage_type"] = storage_type
        if aws_authentication_mode is not UNSET:
            field_dict["aws_authentication_mode"] = aws_authentication_mode
        if azure_authentication_mode is not UNSET:
            field_dict["azure_authentication_mode"] = azure_authentication_mode
        if user is not UNSET:
            field_dict["user"] = user
        if password is not UNSET:
            field_dict["password"] = password
        if region is not UNSET:
            field_dict["region"] = region
        if tenant_id is not UNSET:
            field_dict["tenant_id"] = tenant_id
        if client_id is not UNSET:
            field_dict["client_id"] = client_id
        if client_secret is not UNSET:
            field_dict["client_secret"] = client_secret
        if account_name is not UNSET:
            field_dict["account_name"] = account_name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.avro_file_format_spec import AvroFileFormatSpec
        from ..models.csv_file_format_spec import CsvFileFormatSpec
        from ..models.delta_lake_file_format_spec import DeltaLakeFileFormatSpec
        from ..models.duckdb_parameters_spec_directories import (
            DuckdbParametersSpecDirectories,
        )
        from ..models.duckdb_parameters_spec_properties import (
            DuckdbParametersSpecProperties,
        )
        from ..models.iceberg_file_format_spec import IcebergFileFormatSpec
        from ..models.json_file_format_spec import JsonFileFormatSpec
        from ..models.parquet_file_format_spec import ParquetFileFormatSpec

        d = src_dict.copy()
        _read_mode = d.pop("read_mode", UNSET)
        read_mode: Union[Unset, DuckdbReadMode]
        if isinstance(_read_mode, Unset):
            read_mode = UNSET
        else:
            read_mode = DuckdbReadMode(_read_mode)

        _files_format_type = d.pop("files_format_type", UNSET)
        files_format_type: Union[Unset, DuckdbFilesFormatType]
        if isinstance(_files_format_type, Unset):
            files_format_type = UNSET
        else:
            files_format_type = DuckdbFilesFormatType(_files_format_type)

        database = d.pop("database", UNSET)

        _properties = d.pop("properties", UNSET)
        properties: Union[Unset, DuckdbParametersSpecProperties]
        if isinstance(_properties, Unset):
            properties = UNSET
        else:
            properties = DuckdbParametersSpecProperties.from_dict(_properties)

        _csv = d.pop("csv", UNSET)
        csv: Union[Unset, CsvFileFormatSpec]
        if isinstance(_csv, Unset):
            csv = UNSET
        else:
            csv = CsvFileFormatSpec.from_dict(_csv)

        _json = d.pop("json", UNSET)
        json: Union[Unset, JsonFileFormatSpec]
        if isinstance(_json, Unset):
            json = UNSET
        else:
            json = JsonFileFormatSpec.from_dict(_json)

        _parquet = d.pop("parquet", UNSET)
        parquet: Union[Unset, ParquetFileFormatSpec]
        if isinstance(_parquet, Unset):
            parquet = UNSET
        else:
            parquet = ParquetFileFormatSpec.from_dict(_parquet)

        _avro = d.pop("avro", UNSET)
        avro: Union[Unset, AvroFileFormatSpec]
        if isinstance(_avro, Unset):
            avro = UNSET
        else:
            avro = AvroFileFormatSpec.from_dict(_avro)

        _iceberg = d.pop("iceberg", UNSET)
        iceberg: Union[Unset, IcebergFileFormatSpec]
        if isinstance(_iceberg, Unset):
            iceberg = UNSET
        else:
            iceberg = IcebergFileFormatSpec.from_dict(_iceberg)

        _delta_lake = d.pop("delta_lake", UNSET)
        delta_lake: Union[Unset, DeltaLakeFileFormatSpec]
        if isinstance(_delta_lake, Unset):
            delta_lake = UNSET
        else:
            delta_lake = DeltaLakeFileFormatSpec.from_dict(_delta_lake)

        _directories = d.pop("directories", UNSET)
        directories: Union[Unset, DuckdbParametersSpecDirectories]
        if isinstance(_directories, Unset):
            directories = UNSET
        else:
            directories = DuckdbParametersSpecDirectories.from_dict(_directories)

        _storage_type = d.pop("storage_type", UNSET)
        storage_type: Union[Unset, DuckdbStorageType]
        if isinstance(_storage_type, Unset):
            storage_type = UNSET
        else:
            storage_type = DuckdbStorageType(_storage_type)

        _aws_authentication_mode = d.pop("aws_authentication_mode", UNSET)
        aws_authentication_mode: Union[Unset, AwsAuthenticationMode]
        if isinstance(_aws_authentication_mode, Unset):
            aws_authentication_mode = UNSET
        else:
            aws_authentication_mode = AwsAuthenticationMode(_aws_authentication_mode)

        _azure_authentication_mode = d.pop("azure_authentication_mode", UNSET)
        azure_authentication_mode: Union[Unset, AzureAuthenticationMode]
        if isinstance(_azure_authentication_mode, Unset):
            azure_authentication_mode = UNSET
        else:
            azure_authentication_mode = AzureAuthenticationMode(
                _azure_authentication_mode
            )

        user = d.pop("user", UNSET)

        password = d.pop("password", UNSET)

        region = d.pop("region", UNSET)

        tenant_id = d.pop("tenant_id", UNSET)

        client_id = d.pop("client_id", UNSET)

        client_secret = d.pop("client_secret", UNSET)

        account_name = d.pop("account_name", UNSET)

        duckdb_parameters_spec = cls(
            read_mode=read_mode,
            files_format_type=files_format_type,
            database=database,
            properties=properties,
            csv=csv,
            json=json,
            parquet=parquet,
            avro=avro,
            iceberg=iceberg,
            delta_lake=delta_lake,
            directories=directories,
            storage_type=storage_type,
            aws_authentication_mode=aws_authentication_mode,
            azure_authentication_mode=azure_authentication_mode,
            user=user,
            password=password,
            region=region,
            tenant_id=tenant_id,
            client_id=client_id,
            client_secret=client_secret,
            account_name=account_name,
        )

        duckdb_parameters_spec.additional_properties = d
        return duckdb_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="TimestampColumnsSpec")


@_attrs_define
class TimestampColumnsSpec:
    """
    Attributes:
        event_timestamp_column (Union[Unset, str]): Column name that identifies an event timestamp (date/time), such as
            a transaction timestamp, impression timestamp, event timestamp.
        ingestion_timestamp_column (Union[Unset, str]): Column name that contains the timestamp (or date/time) when the
            row was ingested (loaded, inserted) into the table. Use a column that is filled by the data pipeline or ETL
            process at the time of the data loading.
        partition_by_column (Union[Unset, str]): Column name that contains the date, datetime or timestamp column for
            date/time partitioned data. Partition checks (daily partition checks and monthly partition checks) use this
            column in a GROUP BY clause in order to detect data quality issues in each partition separately. It should be a
            DATE type, DATETIME type (using a local server time zone) or a TIMESTAMP type (a UTC absolute time).
    """

    event_timestamp_column: Union[Unset, str] = UNSET
    ingestion_timestamp_column: Union[Unset, str] = UNSET
    partition_by_column: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        event_timestamp_column = self.event_timestamp_column
        ingestion_timestamp_column = self.ingestion_timestamp_column
        partition_by_column = self.partition_by_column

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if event_timestamp_column is not UNSET:
            field_dict["event_timestamp_column"] = event_timestamp_column
        if ingestion_timestamp_column is not UNSET:
            field_dict["ingestion_timestamp_column"] = ingestion_timestamp_column
        if partition_by_column is not UNSET:
            field_dict["partition_by_column"] = partition_by_column

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        event_timestamp_column = d.pop("event_timestamp_column", UNSET)

        ingestion_timestamp_column = d.pop("ingestion_timestamp_column", UNSET)

        partition_by_column = d.pop("partition_by_column", UNSET)

        timestamp_columns_spec = cls(
            event_timestamp_column=event_timestamp_column,
            ingestion_timestamp_column=ingestion_timestamp_column,
            partition_by_column=partition_by_column,
        )

        timestamp_columns_spec.additional_properties = d
        return timestamp_columns_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class DisplayHint(str, Enum):
    COLUMN_NAMES = "column_names"
    REQUIRES_PAID_VERSION = "requires_paid_version"
    TEXTAREA = "textarea"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class FolderSynchronizationStatus(str, Enum):
    CHANGED = "changed"
    SYNCHRONIZING = "synchronizing"
    UNCHANGED = "unchanged"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.check_result_status import CheckResultStatus
from ..types import UNSET, Unset

T = TypeVar("T", bound="CheckResultsOverviewDataModel")


@_attrs_define
class CheckResultsOverviewDataModel:
    """
    Attributes:
        check_hash (Union[Unset, int]): Check hash.
        check_category (Union[Unset, str]): Check category name.
        check_name (Union[Unset, str]): Check name.
        comparison_name (Union[Unset, str]): Optional table comparison name for table comparison checks only.
        time_periods (Union[Unset, List[datetime.datetime]]): List of time periods for the results, returned as a local
            time, sorted from the newest to the oldest.
        time_periods_utc (Union[Unset, List[int]]): List of time periods for the results, returned as absolute UTC time.
        executed_at_timestamps (Union[Unset, List[int]]): List of absolute timestamp (UTC) when the check was executed
            or an error was raised.
        time_period_display_texts (Union[Unset, List[str]]): List of time periods, sorted descending, returned as a text
            with a possible time zone.
        statuses (Union[Unset, List[CheckResultStatus]]): List of check severity levels or an error status, indexes with
            the severity levels match the time periods.
        data_groups (Union[Unset, List[str]]): List of data group names. Identifies the data group with the highest
            severity or error result.
        results (Union[Unset, List[float]]): List of sensor results. Returns the data quality result readout for the
            data group with the alert of the highest severity level.
    """

    check_hash: Union[Unset, int] = UNSET
    check_category: Union[Unset, str] = UNSET
    check_name: Union[Unset, str] = UNSET
    comparison_name: Union[Unset, str] = UNSET
    time_periods: Union[Unset, List[datetime.datetime]] = UNSET
    time_periods_utc: Union[Unset, List[int]] = UNSET
    executed_at_timestamps: Union[Unset, List[int]] = UNSET
    time_period_display_texts: Union[Unset, List[str]] = UNSET
    statuses: Union[Unset, List[CheckResultStatus]] = UNSET
    data_groups: Union[Unset, List[str]] = UNSET
    results: Union[Unset, List[float]] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        check_hash = self.check_hash
        check_category = self.check_category
        check_name = self.check_name
        comparison_name = self.comparison_name
        time_periods: Union[Unset, List[str]] = UNSET
        if not isinstance(self.time_periods, Unset):
            time_periods = []
            for time_periods_item_data in self.time_periods:
                time_periods_item = time_periods_item_data.isoformat()

                time_periods.append(time_periods_item)

        time_periods_utc: Union[Unset, List[int]] = UNSET
        if not isinstance(self.time_periods_utc, Unset):
            time_periods_utc = self.time_periods_utc

        executed_at_timestamps: Union[Unset, List[int]] = UNSET
        if not isinstance(self.executed_at_timestamps, Unset):
            executed_at_timestamps = self.executed_at_timestamps

        time_period_display_texts: Union[Unset, List[str]] = UNSET
        if not isinstance(self.time_period_display_texts, Unset):
            time_period_display_texts = self.time_period_display_texts

        statuses: Union[Unset, List[str]] = UNSET
        if not isinstance(self.statuses, Unset):
            statuses = []
            for statuses_item_data in self.statuses:
                statuses_item = statuses_item_data.value

                statuses.append(statuses_item)

        data_groups: Union[Unset, List[str]] = UNSET
        if not isinstance(self.data_groups, Unset):
            data_groups = self.data_groups

        results: Union[Unset, List[float]] = UNSET
        if not isinstance(self.results, Unset):
            results = self.results

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if check_hash is not UNSET:
            field_dict["checkHash"] = check_hash
        if check_category is not UNSET:
            field_dict["checkCategory"] = check_category
        if check_name is not UNSET:
            field_dict["checkName"] = check_name
        if comparison_name is not UNSET:
            field_dict["comparisonName"] = comparison_name
        if time_periods is not UNSET:
            field_dict["timePeriods"] = time_periods
        if time_periods_utc is not UNSET:
            field_dict["timePeriodsUtc"] = time_periods_utc
        if executed_at_timestamps is not UNSET:
            field_dict["executedAtTimestamps"] = executed_at_timestamps
        if time_period_display_texts is not UNSET:
            field_dict["timePeriodDisplayTexts"] = time_period_display_texts
        if statuses is not UNSET:
            field_dict["statuses"] = statuses
        if data_groups is not UNSET:
            field_dict["dataGroups"] = data_groups
        if results is not UNSET:
            field_dict["results"] = results

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        check_hash = d.pop("checkHash", UNSET)

        check_category = d.pop("checkCategory", UNSET)

        check_name = d.pop("checkName", UNSET)

        comparison_name = d.pop("comparisonName", UNSET)

        time_periods = []
        _time_periods = d.pop("timePeriods", UNSET)
        for time_periods_item_data in _time_periods or []:
            time_periods_item = isoparse(time_periods_item_data)

            time_periods.append(time_periods_item)

        time_periods_utc = cast(List[int], d.pop("timePeriodsUtc", UNSET))

        executed_at_timestamps = cast(List[int], d.pop("executedAtTimestamps", UNSET))

        time_period_display_texts = cast(
            List[str], d.pop("timePeriodDisplayTexts", UNSET)
        )

        statuses = []
        _statuses = d.pop("statuses", UNSET)
        for statuses_item_data in _statuses or []:
            statuses_item = CheckResultStatus(statuses_item_data)

            statuses.append(statuses_item)

        data_groups = cast(List[str], d.pop("dataGroups", UNSET))

        results = cast(List[float], d.pop("results", UNSET))

        check_results_overview_data_model = cls(
            check_hash=check_hash,
            check_category=check_category,
            check_name=check_name,
            comparison_name=comparison_name,
            time_periods=time_periods,
            time_periods_utc=time_periods_utc,
            executed_at_timestamps=executed_at_timestamps,
            time_period_display_texts=time_period_display_texts,
            statuses=statuses,
            data_groups=data_groups,
            results=results,
        )

        check_results_overview_data_model.additional_properties = d
        return check_results_overview_data_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_volume_row_count_statistics_collector_spec import (
        TableVolumeRowCountStatisticsCollectorSpec,
    )


T = TypeVar("T", bound="TableVolumeStatisticsCollectorsSpec")


@_attrs_define
class TableVolumeStatisticsCollectorsSpec:
    """
    Attributes:
        row_count (Union[Unset, TableVolumeRowCountStatisticsCollectorSpec]):
    """

    row_count: Union[Unset, "TableVolumeRowCountStatisticsCollectorSpec"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        row_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.row_count, Unset):
            row_count = self.row_count.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if row_count is not UNSET:
            field_dict["row_count"] = row_count

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_volume_row_count_statistics_collector_spec import (
            TableVolumeRowCountStatisticsCollectorSpec,
        )

        d = src_dict.copy()
        _row_count = d.pop("row_count", UNSET)
        row_count: Union[Unset, TableVolumeRowCountStatisticsCollectorSpec]
        if isinstance(_row_count, Unset):
            row_count = UNSET
        else:
            row_count = TableVolumeRowCountStatisticsCollectorSpec.from_dict(_row_count)

        table_volume_statistics_collectors_spec = cls(
            row_count=row_count,
        )

        table_volume_statistics_collectors_spec.additional_properties = d
        return table_volume_statistics_collectors_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.check_definition_folder_model_folders import (
        CheckDefinitionFolderModelFolders,
    )
    from ..models.check_definition_list_model import CheckDefinitionListModel


T = TypeVar("T", bound="CheckDefinitionFolderModel")


@_attrs_define
class CheckDefinitionFolderModel:
    """Check folder list model with a list of data quality checks in this folder or a list of nested folders.

    Attributes:
        folders (Union[Unset, CheckDefinitionFolderModelFolders]): A dictionary of nested folders with data quality
            checks. The keys are the folder names.
        checks (Union[Unset, List['CheckDefinitionListModel']]): List of data quality checks defined in this folder.
    """

    folders: Union[Unset, "CheckDefinitionFolderModelFolders"] = UNSET
    checks: Union[Unset, List["CheckDefinitionListModel"]] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        folders: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.folders, Unset):
            folders = self.folders.to_dict()

        checks: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.checks, Unset):
            checks = []
            for checks_item_data in self.checks:
                checks_item = checks_item_data.to_dict()

                checks.append(checks_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if folders is not UNSET:
            field_dict["folders"] = folders
        if checks is not UNSET:
            field_dict["checks"] = checks

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.check_definition_folder_model_folders import (
            CheckDefinitionFolderModelFolders,
        )
        from ..models.check_definition_list_model import CheckDefinitionListModel

        d = src_dict.copy()
        _folders = d.pop("folders", UNSET)
        folders: Union[Unset, CheckDefinitionFolderModelFolders]
        if isinstance(_folders, Unset):
            folders = UNSET
        else:
            folders = CheckDefinitionFolderModelFolders.from_dict(_folders)

        checks = []
        _checks = d.pop("checks", UNSET)
        for checks_item_data in _checks or []:
            checks_item = CheckDefinitionListModel.from_dict(checks_item_data)

            checks.append(checks_item)

        check_definition_folder_model = cls(
            folders=folders,
            checks=checks,
        )

        check_definition_folder_model.additional_properties = d
        return check_definition_folder_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.dqo_job_status import DqoJobStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.dqo_job_history_entry_model import DqoJobHistoryEntryModel
    from ..models.dqo_queue_job_id import DqoQueueJobId


T = TypeVar("T", bound="DqoJobChangeModel")


@_attrs_define
class DqoJobChangeModel:
    """
    Attributes:
        status (Union[Unset, DqoJobStatus]):
        job_id (Union[Unset, DqoQueueJobId]): Identifies a single job that was pushed to the job queue.
        change_sequence (Union[Unset, int]):
        updated_model (Union[Unset, DqoJobHistoryEntryModel]):
        status_changed_at (Union[Unset, int]):
        domain_name (Union[Unset, str]):
    """

    status: Union[Unset, DqoJobStatus] = UNSET
    job_id: Union[Unset, "DqoQueueJobId"] = UNSET
    change_sequence: Union[Unset, int] = UNSET
    updated_model: Union[Unset, "DqoJobHistoryEntryModel"] = UNSET
    status_changed_at: Union[Unset, int] = UNSET
    domain_name: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        job_id: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.job_id, Unset):
            job_id = self.job_id.to_dict()

        change_sequence = self.change_sequence
        updated_model: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.updated_model, Unset):
            updated_model = self.updated_model.to_dict()

        status_changed_at = self.status_changed_at
        domain_name = self.domain_name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if status is not UNSET:
            field_dict["status"] = status
        if job_id is not UNSET:
            field_dict["jobId"] = job_id
        if change_sequence is not UNSET:
            field_dict["changeSequence"] = change_sequence
        if updated_model is not UNSET:
            field_dict["updatedModel"] = updated_model
        if status_changed_at is not UNSET:
            field_dict["statusChangedAt"] = status_changed_at
        if domain_name is not UNSET:
            field_dict["domainName"] = domain_name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.dqo_job_history_entry_model import DqoJobHistoryEntryModel
        from ..models.dqo_queue_job_id import DqoQueueJobId

        d = src_dict.copy()
        _status = d.pop("status", UNSET)
        status: Union[Unset, DqoJobStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = DqoJobStatus(_status)

        _job_id = d.pop("jobId", UNSET)
        job_id: Union[Unset, DqoQueueJobId]
        if isinstance(_job_id, Unset):
            job_id = UNSET
        else:
            job_id = DqoQueueJobId.from_dict(_job_id)

        change_sequence = d.pop("changeSequence", UNSET)

        _updated_model = d.pop("updatedModel", UNSET)
        updated_model: Union[Unset, DqoJobHistoryEntryModel]
        if isinstance(_updated_model, Unset):
            updated_model = UNSET
        else:
            updated_model = DqoJobHistoryEntryModel.from_dict(_updated_model)

        status_changed_at = d.pop("statusChangedAt", UNSET)

        domain_name = d.pop("domainName", UNSET)

        dqo_job_change_model = cls(
            status=status,
            job_id=job_id,
            change_sequence=change_sequence,
            updated_model=updated_model,
            status_changed_at=status_changed_at,
            domain_name=domain_name,
        )

        dqo_job_change_model.additional_properties = d
        return dqo_job_change_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class CheckResultsDetailedLoadMode(str, Enum):
    FIRST_DATA_GROUP = "first_data_group"
    MOST_RECENT_PER_GROUP = "most_recent_per_group"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.dqo_root import DqoRoot
from ..models.file_synchronization_direction import FileSynchronizationDirection
from ..types import UNSET, Unset

T = TypeVar("T", bound="SynchronizeRootFolderParameters")


@_attrs_define
class SynchronizeRootFolderParameters:
    """
    Attributes:
        folder (Union[Unset, DqoRoot]):
        direction (Union[Unset, FileSynchronizationDirection]):
        force_refresh_native_table (Union[Unset, bool]):
    """

    folder: Union[Unset, DqoRoot] = UNSET
    direction: Union[Unset, FileSynchronizationDirection] = UNSET
    force_refresh_native_table: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        folder: Union[Unset, str] = UNSET
        if not isinstance(self.folder, Unset):
            folder = self.folder.value

        direction: Union[Unset, str] = UNSET
        if not isinstance(self.direction, Unset):
            direction = self.direction.value

        force_refresh_native_table = self.force_refresh_native_table

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if folder is not UNSET:
            field_dict["folder"] = folder
        if direction is not UNSET:
            field_dict["direction"] = direction
        if force_refresh_native_table is not UNSET:
            field_dict["forceRefreshNativeTable"] = force_refresh_native_table

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _folder = d.pop("folder", UNSET)
        folder: Union[Unset, DqoRoot]
        if isinstance(_folder, Unset):
            folder = UNSET
        else:
            folder = DqoRoot(_folder)

        _direction = d.pop("direction", UNSET)
        direction: Union[Unset, FileSynchronizationDirection]
        if isinstance(_direction, Unset):
            direction = UNSET
        else:
            direction = FileSynchronizationDirection(_direction)

        force_refresh_native_table = d.pop("forceRefreshNativeTable", UNSET)

        synchronize_root_folder_parameters = cls(
            folder=folder,
            direction=direction,
            force_refresh_native_table=force_refresh_native_table,
        )

        synchronize_root_folder_parameters.additional_properties = d
        return synchronize_root_folder_parameters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.error_samples_data_scope import ErrorSamplesDataScope
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.check_search_filters import CheckSearchFilters
    from ..models.error_sampler_result import ErrorSamplerResult
    from ..models.physical_table_name import PhysicalTableName
    from ..models.time_window_filter_parameters import TimeWindowFilterParameters


T = TypeVar("T", bound="CollectErrorSamplesOnTableParameters")


@_attrs_define
class CollectErrorSamplesOnTableParameters:
    """
    Attributes:
        connection (Union[Unset, str]): The name of the target connection.
        max_jobs_per_connection (Union[Unset, int]): The maximum number of concurrent 'collect error samples on table'
            jobs that can be run on this connection. Limits the number of concurrent jobs.
        table (Union[Unset, PhysicalTableName]):
        check_search_filters (Union[Unset, CheckSearchFilters]): Target data quality checks filter, identifies which
            checks on which tables and columns should be executed.
        time_window_filter (Union[Unset, TimeWindowFilterParameters]): Time window configuration for partitioned checks
            (the number of recent days or months to analyze in an incremental mode) or an absolute time range to analyze.
        data_scope (Union[Unset, ErrorSamplesDataScope]):
        dummy_sensor_execution (Union[Unset, bool]): Boolean flag that enables a dummy error samples collection (sensors
            are executed, but the error samples results are not written to the parquet files).
        error_sampler_result (Union[Unset, ErrorSamplerResult]): Returns the result with the summary of the error
            samples collected.
    """

    connection: Union[Unset, str] = UNSET
    max_jobs_per_connection: Union[Unset, int] = UNSET
    table: Union[Unset, "PhysicalTableName"] = UNSET
    check_search_filters: Union[Unset, "CheckSearchFilters"] = UNSET
    time_window_filter: Union[Unset, "TimeWindowFilterParameters"] = UNSET
    data_scope: Union[Unset, ErrorSamplesDataScope] = UNSET
    dummy_sensor_execution: Union[Unset, bool] = UNSET
    error_sampler_result: Union[Unset, "ErrorSamplerResult"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection = self.connection
        max_jobs_per_connection = self.max_jobs_per_connection
        table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.table, Unset):
            table = self.table.to_dict()

        check_search_filters: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.check_search_filters, Unset):
            check_search_filters = self.check_search_filters.to_dict()

        time_window_filter: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.time_window_filter, Unset):
            time_window_filter = self.time_window_filter.to_dict()

        data_scope: Union[Unset, str] = UNSET
        if not isinstance(self.data_scope, Unset):
            data_scope = self.data_scope.value

        dummy_sensor_execution = self.dummy_sensor_execution
        error_sampler_result: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.error_sampler_result, Unset):
            error_sampler_result = self.error_sampler_result.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection is not UNSET:
            field_dict["connection"] = connection
        if max_jobs_per_connection is not UNSET:
            field_dict["max_jobs_per_connection"] = max_jobs_per_connection
        if table is not UNSET:
            field_dict["table"] = table
        if check_search_filters is not UNSET:
            field_dict["check_search_filters"] = check_search_filters
        if time_window_filter is not UNSET:
            field_dict["time_window_filter"] = time_window_filter
        if data_scope is not UNSET:
            field_dict["data_scope"] = data_scope
        if dummy_sensor_execution is not UNSET:
            field_dict["dummy_sensor_execution"] = dummy_sensor_execution
        if error_sampler_result is not UNSET:
            field_dict["error_sampler_result"] = error_sampler_result

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.check_search_filters import CheckSearchFilters
        from ..models.error_sampler_result import ErrorSamplerResult
        from ..models.physical_table_name import PhysicalTableName
        from ..models.time_window_filter_parameters import TimeWindowFilterParameters

        d = src_dict.copy()
        connection = d.pop("connection", UNSET)

        max_jobs_per_connection = d.pop("max_jobs_per_connection", UNSET)

        _table = d.pop("table", UNSET)
        table: Union[Unset, PhysicalTableName]
        if isinstance(_table, Unset):
            table = UNSET
        else:
            table = PhysicalTableName.from_dict(_table)

        _check_search_filters = d.pop("check_search_filters", UNSET)
        check_search_filters: Union[Unset, CheckSearchFilters]
        if isinstance(_check_search_filters, Unset):
            check_search_filters = UNSET
        else:
            check_search_filters = CheckSearchFilters.from_dict(_check_search_filters)

        _time_window_filter = d.pop("time_window_filter", UNSET)
        time_window_filter: Union[Unset, TimeWindowFilterParameters]
        if isinstance(_time_window_filter, Unset):
            time_window_filter = UNSET
        else:
            time_window_filter = TimeWindowFilterParameters.from_dict(
                _time_window_filter
            )

        _data_scope = d.pop("data_scope", UNSET)
        data_scope: Union[Unset, ErrorSamplesDataScope]
        if isinstance(_data_scope, Unset):
            data_scope = UNSET
        else:
            data_scope = ErrorSamplesDataScope(_data_scope)

        dummy_sensor_execution = d.pop("dummy_sensor_execution", UNSET)

        _error_sampler_result = d.pop("error_sampler_result", UNSET)
        error_sampler_result: Union[Unset, ErrorSamplerResult]
        if isinstance(_error_sampler_result, Unset):
            error_sampler_result = UNSET
        else:
            error_sampler_result = ErrorSamplerResult.from_dict(_error_sampler_result)

        collect_error_samples_on_table_parameters = cls(
            connection=connection,
            max_jobs_per_connection=max_jobs_per_connection,
            table=table,
            check_search_filters=check_search_filters,
            time_window_filter=time_window_filter,
            data_scope=data_scope,
            dummy_sensor_execution=dummy_sensor_execution,
            error_sampler_result=error_sampler_result,
        )

        collect_error_samples_on_table_parameters.additional_properties = d
        return collect_error_samples_on_table_parameters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_text_max_word_count_statistics_collector_spec import (
        ColumnTextMaxWordCountStatisticsCollectorSpec,
    )
    from ..models.column_text_min_word_count_statistics_collector_spec import (
        ColumnTextMinWordCountStatisticsCollectorSpec,
    )
    from ..models.column_text_text_datatype_detect_statistics_collector_spec import (
        ColumnTextTextDatatypeDetectStatisticsCollectorSpec,
    )
    from ..models.column_text_text_max_length_statistics_collector_spec import (
        ColumnTextTextMaxLengthStatisticsCollectorSpec,
    )
    from ..models.column_text_text_mean_length_statistics_collector_spec import (
        ColumnTextTextMeanLengthStatisticsCollectorSpec,
    )
    from ..models.column_text_text_min_length_statistics_collector_spec import (
        ColumnTextTextMinLengthStatisticsCollectorSpec,
    )


T = TypeVar("T", bound="ColumnTextStatisticsCollectorsSpec")


@_attrs_define
class ColumnTextStatisticsCollectorsSpec:
    """
    Attributes:
        text_max_length (Union[Unset, ColumnTextTextMaxLengthStatisticsCollectorSpec]):
        text_mean_length (Union[Unset, ColumnTextTextMeanLengthStatisticsCollectorSpec]):
        text_min_length (Union[Unset, ColumnTextTextMinLengthStatisticsCollectorSpec]):
        text_datatype_detect (Union[Unset, ColumnTextTextDatatypeDetectStatisticsCollectorSpec]):
        text_min_word_count (Union[Unset, ColumnTextMinWordCountStatisticsCollectorSpec]):
        text_max_word_count (Union[Unset, ColumnTextMaxWordCountStatisticsCollectorSpec]):
    """

    text_max_length: Union[Unset, "ColumnTextTextMaxLengthStatisticsCollectorSpec"] = (
        UNSET
    )
    text_mean_length: Union[
        Unset, "ColumnTextTextMeanLengthStatisticsCollectorSpec"
    ] = UNSET
    text_min_length: Union[Unset, "ColumnTextTextMinLengthStatisticsCollectorSpec"] = (
        UNSET
    )
    text_datatype_detect: Union[
        Unset, "ColumnTextTextDatatypeDetectStatisticsCollectorSpec"
    ] = UNSET
    text_min_word_count: Union[
        Unset, "ColumnTextMinWordCountStatisticsCollectorSpec"
    ] = UNSET
    text_max_word_count: Union[
        Unset, "ColumnTextMaxWordCountStatisticsCollectorSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        text_max_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.text_max_length, Unset):
            text_max_length = self.text_max_length.to_dict()

        text_mean_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.text_mean_length, Unset):
            text_mean_length = self.text_mean_length.to_dict()

        text_min_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.text_min_length, Unset):
            text_min_length = self.text_min_length.to_dict()

        text_datatype_detect: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.text_datatype_detect, Unset):
            text_datatype_detect = self.text_datatype_detect.to_dict()

        text_min_word_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.text_min_word_count, Unset):
            text_min_word_count = self.text_min_word_count.to_dict()

        text_max_word_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.text_max_word_count, Unset):
            text_max_word_count = self.text_max_word_count.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if text_max_length is not UNSET:
            field_dict["text_max_length"] = text_max_length
        if text_mean_length is not UNSET:
            field_dict["text_mean_length"] = text_mean_length
        if text_min_length is not UNSET:
            field_dict["text_min_length"] = text_min_length
        if text_datatype_detect is not UNSET:
            field_dict["text_datatype_detect"] = text_datatype_detect
        if text_min_word_count is not UNSET:
            field_dict["text_min_word_count"] = text_min_word_count
        if text_max_word_count is not UNSET:
            field_dict["text_max_word_count"] = text_max_word_count

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_text_max_word_count_statistics_collector_spec import (
            ColumnTextMaxWordCountStatisticsCollectorSpec,
        )
        from ..models.column_text_min_word_count_statistics_collector_spec import (
            ColumnTextMinWordCountStatisticsCollectorSpec,
        )
        from ..models.column_text_text_datatype_detect_statistics_collector_spec import (
            ColumnTextTextDatatypeDetectStatisticsCollectorSpec,
        )
        from ..models.column_text_text_max_length_statistics_collector_spec import (
            ColumnTextTextMaxLengthStatisticsCollectorSpec,
        )
        from ..models.column_text_text_mean_length_statistics_collector_spec import (
            ColumnTextTextMeanLengthStatisticsCollectorSpec,
        )
        from ..models.column_text_text_min_length_statistics_collector_spec import (
            ColumnTextTextMinLengthStatisticsCollectorSpec,
        )

        d = src_dict.copy()
        _text_max_length = d.pop("text_max_length", UNSET)
        text_max_length: Union[Unset, ColumnTextTextMaxLengthStatisticsCollectorSpec]
        if isinstance(_text_max_length, Unset):
            text_max_length = UNSET
        else:
            text_max_length = ColumnTextTextMaxLengthStatisticsCollectorSpec.from_dict(
                _text_max_length
            )

        _text_mean_length = d.pop("text_mean_length", UNSET)
        text_mean_length: Union[Unset, ColumnTextTextMeanLengthStatisticsCollectorSpec]
        if isinstance(_text_mean_length, Unset):
            text_mean_length = UNSET
        else:
            text_mean_length = (
                ColumnTextTextMeanLengthStatisticsCollectorSpec.from_dict(
                    _text_mean_length
                )
            )

        _text_min_length = d.pop("text_min_length", UNSET)
        text_min_length: Union[Unset, ColumnTextTextMinLengthStatisticsCollectorSpec]
        if isinstance(_text_min_length, Unset):
            text_min_length = UNSET
        else:
            text_min_length = ColumnTextTextMinLengthStatisticsCollectorSpec.from_dict(
                _text_min_length
            )

        _text_datatype_detect = d.pop("text_datatype_detect", UNSET)
        text_datatype_detect: Union[
            Unset, ColumnTextTextDatatypeDetectStatisticsCollectorSpec
        ]
        if isinstance(_text_datatype_detect, Unset):
            text_datatype_detect = UNSET
        else:
            text_datatype_detect = (
                ColumnTextTextDatatypeDetectStatisticsCollectorSpec.from_dict(
                    _text_datatype_detect
                )
            )

        _text_min_word_count = d.pop("text_min_word_count", UNSET)
        text_min_word_count: Union[Unset, ColumnTextMinWordCountStatisticsCollectorSpec]
        if isinstance(_text_min_word_count, Unset):
            text_min_word_count = UNSET
        else:
            text_min_word_count = (
                ColumnTextMinWordCountStatisticsCollectorSpec.from_dict(
                    _text_min_word_count
                )
            )

        _text_max_word_count = d.pop("text_max_word_count", UNSET)
        text_max_word_count: Union[Unset, ColumnTextMaxWordCountStatisticsCollectorSpec]
        if isinstance(_text_max_word_count, Unset):
            text_max_word_count = UNSET
        else:
            text_max_word_count = (
                ColumnTextMaxWordCountStatisticsCollectorSpec.from_dict(
                    _text_max_word_count
                )
            )

        column_text_statistics_collectors_spec = cls(
            text_max_length=text_max_length,
            text_mean_length=text_mean_length,
            text_min_length=text_min_length,
            text_datatype_detect=text_datatype_detect,
            text_min_word_count=text_min_word_count,
            text_max_word_count=text_max_word_count,
        )

        column_text_statistics_collectors_spec.additional_properties = d
        return column_text_statistics_collectors_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_integrity_foreign_key_match_percent_check_spec import (
        ColumnIntegrityForeignKeyMatchPercentCheckSpec,
    )
    from ..models.column_integrity_lookup_key_not_found_count_check_spec import (
        ColumnIntegrityLookupKeyNotFoundCountCheckSpec,
    )
    from ..models.column_integrity_monthly_monitoring_checks_spec_custom_checks import (
        ColumnIntegrityMonthlyMonitoringChecksSpecCustomChecks,
    )


T = TypeVar("T", bound="ColumnIntegrityMonthlyMonitoringChecksSpec")


@_attrs_define
class ColumnIntegrityMonthlyMonitoringChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnIntegrityMonthlyMonitoringChecksSpecCustomChecks]): Dictionary of additional
            custom checks within this category. The keys are check names defined in the definition section. The sensor
            parameters and rules should match the type of the configured sensor and rule for the custom check.
        monthly_lookup_key_not_found (Union[Unset, ColumnIntegrityLookupKeyNotFoundCountCheckSpec]):
        monthly_lookup_key_found_percent (Union[Unset, ColumnIntegrityForeignKeyMatchPercentCheckSpec]):
    """

    custom_checks: Union[
        Unset, "ColumnIntegrityMonthlyMonitoringChecksSpecCustomChecks"
    ] = UNSET
    monthly_lookup_key_not_found: Union[
        Unset, "ColumnIntegrityLookupKeyNotFoundCountCheckSpec"
    ] = UNSET
    monthly_lookup_key_found_percent: Union[
        Unset, "ColumnIntegrityForeignKeyMatchPercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        monthly_lookup_key_not_found: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_lookup_key_not_found, Unset):
            monthly_lookup_key_not_found = self.monthly_lookup_key_not_found.to_dict()

        monthly_lookup_key_found_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_lookup_key_found_percent, Unset):
            monthly_lookup_key_found_percent = (
                self.monthly_lookup_key_found_percent.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if monthly_lookup_key_not_found is not UNSET:
            field_dict["monthly_lookup_key_not_found"] = monthly_lookup_key_not_found
        if monthly_lookup_key_found_percent is not UNSET:
            field_dict["monthly_lookup_key_found_percent"] = (
                monthly_lookup_key_found_percent
            )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_integrity_foreign_key_match_percent_check_spec import (
            ColumnIntegrityForeignKeyMatchPercentCheckSpec,
        )
        from ..models.column_integrity_lookup_key_not_found_count_check_spec import (
            ColumnIntegrityLookupKeyNotFoundCountCheckSpec,
        )
        from ..models.column_integrity_monthly_monitoring_checks_spec_custom_checks import (
            ColumnIntegrityMonthlyMonitoringChecksSpecCustomChecks,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[
            Unset, ColumnIntegrityMonthlyMonitoringChecksSpecCustomChecks
        ]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = (
                ColumnIntegrityMonthlyMonitoringChecksSpecCustomChecks.from_dict(
                    _custom_checks
                )
            )

        _monthly_lookup_key_not_found = d.pop("monthly_lookup_key_not_found", UNSET)
        monthly_lookup_key_not_found: Union[
            Unset, ColumnIntegrityLookupKeyNotFoundCountCheckSpec
        ]
        if isinstance(_monthly_lookup_key_not_found, Unset):
            monthly_lookup_key_not_found = UNSET
        else:
            monthly_lookup_key_not_found = (
                ColumnIntegrityLookupKeyNotFoundCountCheckSpec.from_dict(
                    _monthly_lookup_key_not_found
                )
            )

        _monthly_lookup_key_found_percent = d.pop(
            "monthly_lookup_key_found_percent", UNSET
        )
        monthly_lookup_key_found_percent: Union[
            Unset, ColumnIntegrityForeignKeyMatchPercentCheckSpec
        ]
        if isinstance(_monthly_lookup_key_found_percent, Unset):
            monthly_lookup_key_found_percent = UNSET
        else:
            monthly_lookup_key_found_percent = (
                ColumnIntegrityForeignKeyMatchPercentCheckSpec.from_dict(
                    _monthly_lookup_key_found_percent
                )
            )

        column_integrity_monthly_monitoring_checks_spec = cls(
            custom_checks=custom_checks,
            monthly_lookup_key_not_found=monthly_lookup_key_not_found,
            monthly_lookup_key_found_percent=monthly_lookup_key_found_percent,
        )

        column_integrity_monthly_monitoring_checks_spec.additional_properties = d
        return column_integrity_monthly_monitoring_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.delete_stored_data_result_partition_results import (
        DeleteStoredDataResultPartitionResults,
    )


T = TypeVar("T", bound="DeleteStoredDataResult")


@_attrs_define
class DeleteStoredDataResult:
    """
    Attributes:
        partition_results (Union[Unset, DeleteStoredDataResultPartitionResults]): Dictionary of partitions that where
            deleted or updated when the rows were deleted.
    """

    partition_results: Union[Unset, "DeleteStoredDataResultPartitionResults"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        partition_results: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.partition_results, Unset):
            partition_results = self.partition_results.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if partition_results is not UNSET:
            field_dict["partitionResults"] = partition_results

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.delete_stored_data_result_partition_results import (
            DeleteStoredDataResultPartitionResults,
        )

        d = src_dict.copy()
        _partition_results = d.pop("partitionResults", UNSET)
        partition_results: Union[Unset, DeleteStoredDataResultPartitionResults]
        if isinstance(_partition_results, Unset):
            partition_results = UNSET
        else:
            partition_results = DeleteStoredDataResultPartitionResults.from_dict(
                _partition_results
            )

        delete_stored_data_result = cls(
            partition_results=partition_results,
        )

        delete_stored_data_result.additional_properties = d
        return delete_stored_data_result

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.dqo_job_status import DqoJobStatus
from ..models.dqo_job_type import DqoJobType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.dqo_job_entry_parameters_model import DqoJobEntryParametersModel
    from ..models.dqo_queue_job_id import DqoQueueJobId


T = TypeVar("T", bound="DqoJobHistoryEntryModel")


@_attrs_define
class DqoJobHistoryEntryModel:
    """
    Attributes:
        job_id (Union[Unset, DqoQueueJobId]): Identifies a single job that was pushed to the job queue.
        job_type (Union[Unset, DqoJobType]):
        parameters (Union[Unset, DqoJobEntryParametersModel]):
        status (Union[Unset, DqoJobStatus]):
        error_message (Union[Unset, str]):
        status_changed_at (Union[Unset, int]):
        data_domain (Union[Unset, str]):
    """

    job_id: Union[Unset, "DqoQueueJobId"] = UNSET
    job_type: Union[Unset, DqoJobType] = UNSET
    parameters: Union[Unset, "DqoJobEntryParametersModel"] = UNSET
    status: Union[Unset, DqoJobStatus] = UNSET
    error_message: Union[Unset, str] = UNSET
    status_changed_at: Union[Unset, int] = UNSET
    data_domain: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        job_id: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.job_id, Unset):
            job_id = self.job_id.to_dict()

        job_type: Union[Unset, str] = UNSET
        if not isinstance(self.job_type, Unset):
            job_type = self.job_type.value

        parameters: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.parameters, Unset):
            parameters = self.parameters.to_dict()

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        error_message = self.error_message
        status_changed_at = self.status_changed_at
        data_domain = self.data_domain

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if job_id is not UNSET:
            field_dict["jobId"] = job_id
        if job_type is not UNSET:
            field_dict["jobType"] = job_type
        if parameters is not UNSET:
            field_dict["parameters"] = parameters
        if status is not UNSET:
            field_dict["status"] = status
        if error_message is not UNSET:
            field_dict["errorMessage"] = error_message
        if status_changed_at is not UNSET:
            field_dict["statusChangedAt"] = status_changed_at
        if data_domain is not UNSET:
            field_dict["dataDomain"] = data_domain

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.dqo_job_entry_parameters_model import DqoJobEntryParametersModel
        from ..models.dqo_queue_job_id import DqoQueueJobId

        d = src_dict.copy()
        _job_id = d.pop("jobId", UNSET)
        job_id: Union[Unset, DqoQueueJobId]
        if isinstance(_job_id, Unset):
            job_id = UNSET
        else:
            job_id = DqoQueueJobId.from_dict(_job_id)

        _job_type = d.pop("jobType", UNSET)
        job_type: Union[Unset, DqoJobType]
        if isinstance(_job_type, Unset):
            job_type = UNSET
        else:
            job_type = DqoJobType(_job_type)

        _parameters = d.pop("parameters", UNSET)
        parameters: Union[Unset, DqoJobEntryParametersModel]
        if isinstance(_parameters, Unset):
            parameters = UNSET
        else:
            parameters = DqoJobEntryParametersModel.from_dict(_parameters)

        _status = d.pop("status", UNSET)
        status: Union[Unset, DqoJobStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = DqoJobStatus(_status)

        error_message = d.pop("errorMessage", UNSET)

        status_changed_at = d.pop("statusChangedAt", UNSET)

        data_domain = d.pop("dataDomain", UNSET)

        dqo_job_history_entry_model = cls(
            job_id=job_id,
            job_type=job_type,
            parameters=parameters,
            status=status,
            error_message=error_message,
            status_changed_at=status_changed_at,
            data_domain=data_domain,
        )

        dqo_job_history_entry_model.additional_properties = d
        return dqo_job_history_entry_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.dashboard_spec import DashboardSpec


T = TypeVar("T", bound="AuthenticatedDashboardModel")


@_attrs_define
class AuthenticatedDashboardModel:
    """Describes a single authenticated dashboard.

    Attributes:
        folder_path (Union[Unset, str]): Folder path
        dashboard (Union[Unset, DashboardSpec]):
        authenticated_dashboard_url (Union[Unset, str]): Dashboard authenticated url with a short lived refresh token
    """

    folder_path: Union[Unset, str] = UNSET
    dashboard: Union[Unset, "DashboardSpec"] = UNSET
    authenticated_dashboard_url: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        folder_path = self.folder_path
        dashboard: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.dashboard, Unset):
            dashboard = self.dashboard.to_dict()

        authenticated_dashboard_url = self.authenticated_dashboard_url

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if folder_path is not UNSET:
            field_dict["folder_path"] = folder_path
        if dashboard is not UNSET:
            field_dict["dashboard"] = dashboard
        if authenticated_dashboard_url is not UNSET:
            field_dict["authenticated_dashboard_url"] = authenticated_dashboard_url

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.dashboard_spec import DashboardSpec

        d = src_dict.copy()
        folder_path = d.pop("folder_path", UNSET)

        _dashboard = d.pop("dashboard", UNSET)
        dashboard: Union[Unset, DashboardSpec]
        if isinstance(_dashboard, Unset):
            dashboard = UNSET
        else:
            dashboard = DashboardSpec.from_dict(_dashboard)

        authenticated_dashboard_url = d.pop("authenticated_dashboard_url", UNSET)

        authenticated_dashboard_model = cls(
            folder_path=folder_path,
            dashboard=dashboard,
            authenticated_dashboard_url=authenticated_dashboard_url,
        )

        authenticated_dashboard_model.additional_properties = d
        return authenticated_dashboard_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_type_snapshot_spec import ColumnTypeSnapshotSpec
    from ..models.physical_table_name import PhysicalTableName
    from ..models.statistics_collector_search_filters import (
        StatisticsCollectorSearchFilters,
    )
    from ..models.statistics_metric_model import StatisticsMetricModel


T = TypeVar("T", bound="ColumnStatisticsModel")


@_attrs_define
class ColumnStatisticsModel:
    """Column model that returns the basic fields from a column specification with the additional data statistics.

    Attributes:
        connection_name (Union[Unset, str]): Connection name.
        table (Union[Unset, PhysicalTableName]):
        column_name (Union[Unset, str]): Column name.
        column_hash (Union[Unset, int]): Column hash that identifies the column using a unique hash code.
        disabled (Union[Unset, bool]): Disables all data quality checks on the column. Data quality checks will not be
            executed.
        has_any_configured_checks (Union[Unset, bool]): True when the column has any checks configured.
        type_snapshot (Union[Unset, ColumnTypeSnapshotSpec]):
        statistics (Union[Unset, List['StatisticsMetricModel']]): List of collected column statistics.
        collect_column_statistics_job_template (Union[Unset, StatisticsCollectorSearchFilters]):
        can_collect_statistics (Union[Unset, bool]): Boolean flag that decides if the current user can collect
            statistics.
    """

    connection_name: Union[Unset, str] = UNSET
    table: Union[Unset, "PhysicalTableName"] = UNSET
    column_name: Union[Unset, str] = UNSET
    column_hash: Union[Unset, int] = UNSET
    disabled: Union[Unset, bool] = UNSET
    has_any_configured_checks: Union[Unset, bool] = UNSET
    type_snapshot: Union[Unset, "ColumnTypeSnapshotSpec"] = UNSET
    statistics: Union[Unset, List["StatisticsMetricModel"]] = UNSET
    collect_column_statistics_job_template: Union[
        Unset, "StatisticsCollectorSearchFilters"
    ] = UNSET
    can_collect_statistics: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection_name = self.connection_name
        table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.table, Unset):
            table = self.table.to_dict()

        column_name = self.column_name
        column_hash = self.column_hash
        disabled = self.disabled
        has_any_configured_checks = self.has_any_configured_checks
        type_snapshot: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.type_snapshot, Unset):
            type_snapshot = self.type_snapshot.to_dict()

        statistics: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.statistics, Unset):
            statistics = []
            for statistics_item_data in self.statistics:
                statistics_item = statistics_item_data.to_dict()

                statistics.append(statistics_item)

        collect_column_statistics_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.collect_column_statistics_job_template, Unset):
            collect_column_statistics_job_template = (
                self.collect_column_statistics_job_template.to_dict()
            )

        can_collect_statistics = self.can_collect_statistics

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection_name is not UNSET:
            field_dict["connection_name"] = connection_name
        if table is not UNSET:
            field_dict["table"] = table
        if column_name is not UNSET:
            field_dict["column_name"] = column_name
        if column_hash is not UNSET:
            field_dict["column_hash"] = column_hash
        if disabled is not UNSET:
            field_dict["disabled"] = disabled
        if has_any_configured_checks is not UNSET:
            field_dict["has_any_configured_checks"] = has_any_configured_checks
        if type_snapshot is not UNSET:
            field_dict["type_snapshot"] = type_snapshot
        if statistics is not UNSET:
            field_dict["statistics"] = statistics
        if collect_column_statistics_job_template is not UNSET:
            field_dict["collect_column_statistics_job_template"] = (
                collect_column_statistics_job_template
            )
        if can_collect_statistics is not UNSET:
            field_dict["can_collect_statistics"] = can_collect_statistics

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_type_snapshot_spec import ColumnTypeSnapshotSpec
        from ..models.physical_table_name import PhysicalTableName
        from ..models.statistics_collector_search_filters import (
            StatisticsCollectorSearchFilters,
        )
        from ..models.statistics_metric_model import StatisticsMetricModel

        d = src_dict.copy()
        connection_name = d.pop("connection_name", UNSET)

        _table = d.pop("table", UNSET)
        table: Union[Unset, PhysicalTableName]
        if isinstance(_table, Unset):
            table = UNSET
        else:
            table = PhysicalTableName.from_dict(_table)

        column_name = d.pop("column_name", UNSET)

        column_hash = d.pop("column_hash", UNSET)

        disabled = d.pop("disabled", UNSET)

        has_any_configured_checks = d.pop("has_any_configured_checks", UNSET)

        _type_snapshot = d.pop("type_snapshot", UNSET)
        type_snapshot: Union[Unset, ColumnTypeSnapshotSpec]
        if isinstance(_type_snapshot, Unset):
            type_snapshot = UNSET
        else:
            type_snapshot = ColumnTypeSnapshotSpec.from_dict(_type_snapshot)

        statistics = []
        _statistics = d.pop("statistics", UNSET)
        for statistics_item_data in _statistics or []:
            statistics_item = StatisticsMetricModel.from_dict(statistics_item_data)

            statistics.append(statistics_item)

        _collect_column_statistics_job_template = d.pop(
            "collect_column_statistics_job_template", UNSET
        )
        collect_column_statistics_job_template: Union[
            Unset, StatisticsCollectorSearchFilters
        ]
        if isinstance(_collect_column_statistics_job_template, Unset):
            collect_column_statistics_job_template = UNSET
        else:
            collect_column_statistics_job_template = (
                StatisticsCollectorSearchFilters.from_dict(
                    _collect_column_statistics_job_template
                )
            )

        can_collect_statistics = d.pop("can_collect_statistics", UNSET)

        column_statistics_model = cls(
            connection_name=connection_name,
            table=table,
            column_name=column_name,
            column_hash=column_hash,
            disabled=disabled,
            has_any_configured_checks=has_any_configured_checks,
            type_snapshot=type_snapshot,
            statistics=statistics,
            collect_column_statistics_job_template=collect_column_statistics_job_template,
            can_collect_statistics=can_collect_statistics,
        )

        column_statistics_model.additional_properties = d
        return column_statistics_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.comment_spec import CommentSpec
    from ..models.cron_schedules_spec import CronSchedulesSpec
    from ..models.file_format_spec import FileFormatSpec
    from ..models.partition_incremental_time_window_spec import (
        PartitionIncrementalTimeWindowSpec,
    )
    from ..models.table_incident_grouping_spec import TableIncidentGroupingSpec
    from ..models.table_lineage_source_spec import TableLineageSourceSpec
    from ..models.table_monitoring_check_categories_spec import (
        TableMonitoringCheckCategoriesSpec,
    )
    from ..models.table_owner_spec import TableOwnerSpec
    from ..models.table_partitioned_check_categories_spec import (
        TablePartitionedCheckCategoriesSpec,
    )
    from ..models.table_profiling_check_categories_spec import (
        TableProfilingCheckCategoriesSpec,
    )
    from ..models.table_spec_advanced_properties import TableSpecAdvancedProperties
    from ..models.table_spec_columns import TableSpecColumns
    from ..models.table_spec_groupings import TableSpecGroupings
    from ..models.table_spec_table_comparisons import TableSpecTableComparisons
    from ..models.table_statistics_collectors_root_categories_spec import (
        TableStatisticsCollectorsRootCategoriesSpec,
    )
    from ..models.timestamp_columns_spec import TimestampColumnsSpec


T = TypeVar("T", bound="TableSpec")


@_attrs_define
class TableSpec:
    """
    Attributes:
        disabled (Union[Unset, bool]): Disables all data quality checks on the table. Data quality checks will not be
            executed.
        stage (Union[Unset, str]): Stage name.
        priority (Union[Unset, int]): Table priority (1, 2, 3, 4, ...). The tables can be assigned a priority level. The
            table priority is copied into each data quality check result and a sensor result, enabling efficient grouping of
            more and less important tables during a data quality improvement project, when the data quality issues on higher
            priority tables are fixed before data quality issues on less important tables.
        filter_ (Union[Unset, str]): SQL WHERE clause added to the sensor queries. Use replacement tokens {table} to
            replace the content with the full table name, {alias} to replace the content with the table alias of an analyzed
            table or {column} to replace the content with the analyzed column name.
        do_not_collect_error_samples_in_profiling (Union[Unset, bool]): Disable automatic collection of error samples in
            the profiling section. The profiling checks by default always collect error samples for failed data quality
            checks.
        always_collect_error_samples_in_monitoring (Union[Unset, bool]): Always collect error samples for failed
            monitoring checks. DQOps will not collect error samples automatically when the checks are executed by a
            scheduler or by running checks from the metadata tree. Error samples are always collected only when the checks
            are run from the check editor.
        timestamp_columns (Union[Unset, TimestampColumnsSpec]):
        incremental_time_window (Union[Unset, PartitionIncrementalTimeWindowSpec]):
        default_grouping_name (Union[Unset, str]): The name of the default data grouping configuration that is applied
            on data quality checks. When a default data grouping is selected, all data quality checks run SQL queries with a
            GROUP BY clause, calculating separate data quality checks for each group of data. The data groupings are defined
            in the 'groupings' dictionary (indexed by the data grouping name).
        groupings (Union[Unset, TableSpecGroupings]): Data grouping configurations list. Data grouping configurations
            are configured in two cases: (1) the data in the table should be analyzed with a GROUP BY condition, to analyze
            different datasets using separate time series, for example a table contains data from multiple countries and
            there is a 'country' column used for partitioning. (2) a tag is assigned to a table (within a data grouping
            level hierarchy), when the data is segmented at a table level (similar tables store the same information, but
            for different countries, etc.).
        table_comparisons (Union[Unset, TableSpecTableComparisons]): Dictionary of data comparison configurations. Data
            comparison configurations are used for comparisons between data sources to compare this table (called the
            compared table) with other reference tables (the source of truth). The reference table's metadata must be
            imported into DQOps, but the reference table may be located in another data source. DQOps will compare metrics
            calculated for groups of rows (using the GROUP BY clause). For each comparison, the user must specify a name of
            a data grouping. The number of data grouping dimensions in the parent table and the reference table defined in
            the selected data grouping configurations must match. DQOps will run the same data quality sensors on both the
            parent table (table under test) and the reference table (the source of truth), comparing the measures (sensor
            readouts) captured from both tables.
        incident_grouping (Union[Unset, TableIncidentGroupingSpec]):
        owner (Union[Unset, TableOwnerSpec]):
        profiling_checks (Union[Unset, TableProfilingCheckCategoriesSpec]):
        monitoring_checks (Union[Unset, TableMonitoringCheckCategoriesSpec]):
        partitioned_checks (Union[Unset, TablePartitionedCheckCategoriesSpec]):
        statistics (Union[Unset, TableStatisticsCollectorsRootCategoriesSpec]):
        schedules_override (Union[Unset, CronSchedulesSpec]):
        columns (Union[Unset, TableSpecColumns]): Dictionary of columns, indexed by a physical column name. Column
            specification contains the expected column data type and a list of column level data quality checks that are
            enabled for a column.
        labels (Union[Unset, List[str]]): Custom labels that were assigned to the table. Labels are used for searching
            for tables when filtered data quality checks are executed.
        comments (Union[Unset, List['CommentSpec']]): Comments used for change tracking and documenting changes directly
            in the table data quality specification file.
        file_format (Union[Unset, FileFormatSpec]):
        advanced_properties (Union[Unset, TableSpecAdvancedProperties]): A dictionary of advanced properties that can be
            used for e.g. to support mapping data to data catalogs, a key/value dictionary.
        source_tables (Union[Unset, List['TableLineageSourceSpec']]): A list of source tables. This information is used
            to define the data lineage report for the table.
    """

    disabled: Union[Unset, bool] = UNSET
    stage: Union[Unset, str] = UNSET
    priority: Union[Unset, int] = UNSET
    filter_: Union[Unset, str] = UNSET
    do_not_collect_error_samples_in_profiling: Union[Unset, bool] = UNSET
    always_collect_error_samples_in_monitoring: Union[Unset, bool] = UNSET
    timestamp_columns: Union[Unset, "TimestampColumnsSpec"] = UNSET
    incremental_time_window: Union[Unset, "PartitionIncrementalTimeWindowSpec"] = UNSET
    default_grouping_name: Union[Unset, str] = UNSET
    groupings: Union[Unset, "TableSpecGroupings"] = UNSET
    table_comparisons: Union[Unset, "TableSpecTableComparisons"] = UNSET
    incident_grouping: Union[Unset, "TableIncidentGroupingSpec"] = UNSET
    owner: Union[Unset, "TableOwnerSpec"] = UNSET
    profiling_checks: Union[Unset, "TableProfilingCheckCategoriesSpec"] = UNSET
    monitoring_checks: Union[Unset, "TableMonitoringCheckCategoriesSpec"] = UNSET
    partitioned_checks: Union[Unset, "TablePartitionedCheckCategoriesSpec"] = UNSET
    statistics: Union[Unset, "TableStatisticsCollectorsRootCategoriesSpec"] = UNSET
    schedules_override: Union[Unset, "CronSchedulesSpec"] = UNSET
    columns: Union[Unset, "TableSpecColumns"] = UNSET
    labels: Union[Unset, List[str]] = UNSET
    comments: Union[Unset, List["CommentSpec"]] = UNSET
    file_format: Union[Unset, "FileFormatSpec"] = UNSET
    advanced_properties: Union[Unset, "TableSpecAdvancedProperties"] = UNSET
    source_tables: Union[Unset, List["TableLineageSourceSpec"]] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        disabled = self.disabled
        stage = self.stage
        priority = self.priority
        filter_ = self.filter_
        do_not_collect_error_samples_in_profiling = (
            self.do_not_collect_error_samples_in_profiling
        )
        always_collect_error_samples_in_monitoring = (
            self.always_collect_error_samples_in_monitoring
        )
        timestamp_columns: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.timestamp_columns, Unset):
            timestamp_columns = self.timestamp_columns.to_dict()

        incremental_time_window: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.incremental_time_window, Unset):
            incremental_time_window = self.incremental_time_window.to_dict()

        default_grouping_name = self.default_grouping_name
        groupings: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.groupings, Unset):
            groupings = self.groupings.to_dict()

        table_comparisons: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.table_comparisons, Unset):
            table_comparisons = self.table_comparisons.to_dict()

        incident_grouping: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.incident_grouping, Unset):
            incident_grouping = self.incident_grouping.to_dict()

        owner: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.owner, Unset):
            owner = self.owner.to_dict()

        profiling_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profiling_checks, Unset):
            profiling_checks = self.profiling_checks.to_dict()

        monitoring_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monitoring_checks, Unset):
            monitoring_checks = self.monitoring_checks.to_dict()

        partitioned_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.partitioned_checks, Unset):
            partitioned_checks = self.partitioned_checks.to_dict()

        statistics: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.statistics, Unset):
            statistics = self.statistics.to_dict()

        schedules_override: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.schedules_override, Unset):
            schedules_override = self.schedules_override.to_dict()

        columns: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.columns, Unset):
            columns = self.columns.to_dict()

        labels: Union[Unset, List[str]] = UNSET
        if not isinstance(self.labels, Unset):
            labels = self.labels

        comments: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.comments, Unset):
            comments = []
            for comments_item_data in self.comments:
                comments_item = comments_item_data.to_dict()

                comments.append(comments_item)

        file_format: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.file_format, Unset):
            file_format = self.file_format.to_dict()

        advanced_properties: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.advanced_properties, Unset):
            advanced_properties = self.advanced_properties.to_dict()

        source_tables: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.source_tables, Unset):
            source_tables = []
            for source_tables_item_data in self.source_tables:
                source_tables_item = source_tables_item_data.to_dict()

                source_tables.append(source_tables_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if disabled is not UNSET:
            field_dict["disabled"] = disabled
        if stage is not UNSET:
            field_dict["stage"] = stage
        if priority is not UNSET:
            field_dict["priority"] = priority
        if filter_ is not UNSET:
            field_dict["filter"] = filter_
        if do_not_collect_error_samples_in_profiling is not UNSET:
            field_dict["do_not_collect_error_samples_in_profiling"] = (
                do_not_collect_error_samples_in_profiling
            )
        if always_collect_error_samples_in_monitoring is not UNSET:
            field_dict["always_collect_error_samples_in_monitoring"] = (
                always_collect_error_samples_in_monitoring
            )
        if timestamp_columns is not UNSET:
            field_dict["timestamp_columns"] = timestamp_columns
        if incremental_time_window is not UNSET:
            field_dict["incremental_time_window"] = incremental_time_window
        if default_grouping_name is not UNSET:
            field_dict["default_grouping_name"] = default_grouping_name
        if groupings is not UNSET:
            field_dict["groupings"] = groupings
        if table_comparisons is not UNSET:
            field_dict["table_comparisons"] = table_comparisons
        if incident_grouping is not UNSET:
            field_dict["incident_grouping"] = incident_grouping
        if owner is not UNSET:
            field_dict["owner"] = owner
        if profiling_checks is not UNSET:
            field_dict["profiling_checks"] = profiling_checks
        if monitoring_checks is not UNSET:
            field_dict["monitoring_checks"] = monitoring_checks
        if partitioned_checks is not UNSET:
            field_dict["partitioned_checks"] = partitioned_checks
        if statistics is not UNSET:
            field_dict["statistics"] = statistics
        if schedules_override is not UNSET:
            field_dict["schedules_override"] = schedules_override
        if columns is not UNSET:
            field_dict["columns"] = columns
        if labels is not UNSET:
            field_dict["labels"] = labels
        if comments is not UNSET:
            field_dict["comments"] = comments
        if file_format is not UNSET:
            field_dict["file_format"] = file_format
        if advanced_properties is not UNSET:
            field_dict["advanced_properties"] = advanced_properties
        if source_tables is not UNSET:
            field_dict["source_tables"] = source_tables

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.comment_spec import CommentSpec
        from ..models.cron_schedules_spec import CronSchedulesSpec
        from ..models.file_format_spec import FileFormatSpec
        from ..models.partition_incremental_time_window_spec import (
            PartitionIncrementalTimeWindowSpec,
        )
        from ..models.table_incident_grouping_spec import TableIncidentGroupingSpec
        from ..models.table_lineage_source_spec import TableLineageSourceSpec
        from ..models.table_monitoring_check_categories_spec import (
            TableMonitoringCheckCategoriesSpec,
        )
        from ..models.table_owner_spec import TableOwnerSpec
        from ..models.table_partitioned_check_categories_spec import (
            TablePartitionedCheckCategoriesSpec,
        )
        from ..models.table_profiling_check_categories_spec import (
            TableProfilingCheckCategoriesSpec,
        )
        from ..models.table_spec_advanced_properties import TableSpecAdvancedProperties
        from ..models.table_spec_columns import TableSpecColumns
        from ..models.table_spec_groupings import TableSpecGroupings
        from ..models.table_spec_table_comparisons import TableSpecTableComparisons
        from ..models.table_statistics_collectors_root_categories_spec import (
            TableStatisticsCollectorsRootCategoriesSpec,
        )
        from ..models.timestamp_columns_spec import TimestampColumnsSpec

        d = src_dict.copy()
        disabled = d.pop("disabled", UNSET)

        stage = d.pop("stage", UNSET)

        priority = d.pop("priority", UNSET)

        filter_ = d.pop("filter", UNSET)

        do_not_collect_error_samples_in_profiling = d.pop(
            "do_not_collect_error_samples_in_profiling", UNSET
        )

        always_collect_error_samples_in_monitoring = d.pop(
            "always_collect_error_samples_in_monitoring", UNSET
        )

        _timestamp_columns = d.pop("timestamp_columns", UNSET)
        timestamp_columns: Union[Unset, TimestampColumnsSpec]
        if isinstance(_timestamp_columns, Unset):
            timestamp_columns = UNSET
        else:
            timestamp_columns = TimestampColumnsSpec.from_dict(_timestamp_columns)

        _incremental_time_window = d.pop("incremental_time_window", UNSET)
        incremental_time_window: Union[Unset, PartitionIncrementalTimeWindowSpec]
        if isinstance(_incremental_time_window, Unset):
            incremental_time_window = UNSET
        else:
            incremental_time_window = PartitionIncrementalTimeWindowSpec.from_dict(
                _incremental_time_window
            )

        default_grouping_name = d.pop("default_grouping_name", UNSET)

        _groupings = d.pop("groupings", UNSET)
        groupings: Union[Unset, TableSpecGroupings]
        if isinstance(_groupings, Unset):
            groupings = UNSET
        else:
            groupings = TableSpecGroupings.from_dict(_groupings)

        _table_comparisons = d.pop("table_comparisons", UNSET)
        table_comparisons: Union[Unset, TableSpecTableComparisons]
        if isinstance(_table_comparisons, Unset):
            table_comparisons = UNSET
        else:
            table_comparisons = TableSpecTableComparisons.from_dict(_table_comparisons)

        _incident_grouping = d.pop("incident_grouping", UNSET)
        incident_grouping: Union[Unset, TableIncidentGroupingSpec]
        if isinstance(_incident_grouping, Unset):
            incident_grouping = UNSET
        else:
            incident_grouping = TableIncidentGroupingSpec.from_dict(_incident_grouping)

        _owner = d.pop("owner", UNSET)
        owner: Union[Unset, TableOwnerSpec]
        if isinstance(_owner, Unset):
            owner = UNSET
        else:
            owner = TableOwnerSpec.from_dict(_owner)

        _profiling_checks = d.pop("profiling_checks", UNSET)
        profiling_checks: Union[Unset, TableProfilingCheckCategoriesSpec]
        if isinstance(_profiling_checks, Unset):
            profiling_checks = UNSET
        else:
            profiling_checks = TableProfilingCheckCategoriesSpec.from_dict(
                _profiling_checks
            )

        _monitoring_checks = d.pop("monitoring_checks", UNSET)
        monitoring_checks: Union[Unset, TableMonitoringCheckCategoriesSpec]
        if isinstance(_monitoring_checks, Unset):
            monitoring_checks = UNSET
        else:
            monitoring_checks = TableMonitoringCheckCategoriesSpec.from_dict(
                _monitoring_checks
            )

        _partitioned_checks = d.pop("partitioned_checks", UNSET)
        partitioned_checks: Union[Unset, TablePartitionedCheckCategoriesSpec]
        if isinstance(_partitioned_checks, Unset):
            partitioned_checks = UNSET
        else:
            partitioned_checks = TablePartitionedCheckCategoriesSpec.from_dict(
                _partitioned_checks
            )

        _statistics = d.pop("statistics", UNSET)
        statistics: Union[Unset, TableStatisticsCollectorsRootCategoriesSpec]
        if isinstance(_statistics, Unset):
            statistics = UNSET
        else:
            statistics = TableStatisticsCollectorsRootCategoriesSpec.from_dict(
                _statistics
            )

        _schedules_override = d.pop("schedules_override", UNSET)
        schedules_override: Union[Unset, CronSchedulesSpec]
        if isinstance(_schedules_override, Unset):
            schedules_override = UNSET
        else:
            schedules_override = CronSchedulesSpec.from_dict(_schedules_override)

        _columns = d.pop("columns", UNSET)
        columns: Union[Unset, TableSpecColumns]
        if isinstance(_columns, Unset):
            columns = UNSET
        else:
            columns = TableSpecColumns.from_dict(_columns)

        labels = cast(List[str], d.pop("labels", UNSET))

        comments = []
        _comments = d.pop("comments", UNSET)
        for comments_item_data in _comments or []:
            comments_item = CommentSpec.from_dict(comments_item_data)

            comments.append(comments_item)

        _file_format = d.pop("file_format", UNSET)
        file_format: Union[Unset, FileFormatSpec]
        if isinstance(_file_format, Unset):
            file_format = UNSET
        else:
            file_format = FileFormatSpec.from_dict(_file_format)

        _advanced_properties = d.pop("advanced_properties", UNSET)
        advanced_properties: Union[Unset, TableSpecAdvancedProperties]
        if isinstance(_advanced_properties, Unset):
            advanced_properties = UNSET
        else:
            advanced_properties = TableSpecAdvancedProperties.from_dict(
                _advanced_properties
            )

        source_tables = []
        _source_tables = d.pop("source_tables", UNSET)
        for source_tables_item_data in _source_tables or []:
            source_tables_item = TableLineageSourceSpec.from_dict(
                source_tables_item_data
            )

            source_tables.append(source_tables_item)

        table_spec = cls(
            disabled=disabled,
            stage=stage,
            priority=priority,
            filter_=filter_,
            do_not_collect_error_samples_in_profiling=do_not_collect_error_samples_in_profiling,
            always_collect_error_samples_in_monitoring=always_collect_error_samples_in_monitoring,
            timestamp_columns=timestamp_columns,
            incremental_time_window=incremental_time_window,
            default_grouping_name=default_grouping_name,
            groupings=groupings,
            table_comparisons=table_comparisons,
            incident_grouping=incident_grouping,
            owner=owner,
            profiling_checks=profiling_checks,
            monitoring_checks=monitoring_checks,
            partitioned_checks=partitioned_checks,
            statistics=statistics,
            schedules_override=schedules_override,
            columns=columns,
            labels=labels,
            comments=comments,
            file_format=file_format,
            advanced_properties=advanced_properties,
            source_tables=source_tables,
        )

        table_spec.additional_properties = d
        return table_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.temporal_unit import TemporalUnit


T = TypeVar("T", bound="Duration")


@_attrs_define
class Duration:
    """
    Attributes:
        seconds (Union[Unset, int]):
        nano (Union[Unset, int]):
        negative (Union[Unset, bool]):
        zero (Union[Unset, bool]):
        units (Union[Unset, List['TemporalUnit']]):
    """

    seconds: Union[Unset, int] = UNSET
    nano: Union[Unset, int] = UNSET
    negative: Union[Unset, bool] = UNSET
    zero: Union[Unset, bool] = UNSET
    units: Union[Unset, List["TemporalUnit"]] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        seconds = self.seconds
        nano = self.nano
        negative = self.negative
        zero = self.zero
        units: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.units, Unset):
            units = []
            for units_item_data in self.units:
                units_item = units_item_data.to_dict()

                units.append(units_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if seconds is not UNSET:
            field_dict["seconds"] = seconds
        if nano is not UNSET:
            field_dict["nano"] = nano
        if negative is not UNSET:
            field_dict["negative"] = negative
        if zero is not UNSET:
            field_dict["zero"] = zero
        if units is not UNSET:
            field_dict["units"] = units

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.temporal_unit import TemporalUnit

        d = src_dict.copy()
        seconds = d.pop("seconds", UNSET)

        nano = d.pop("nano", UNSET)

        negative = d.pop("negative", UNSET)

        zero = d.pop("zero", UNSET)

        units = []
        _units = d.pop("units", UNSET)
        for units_item_data in _units or []:
            units_item = TemporalUnit.from_dict(units_item_data)

            units.append(units_item)

        duration = cls(
            seconds=seconds,
            nano=nano,
            negative=negative,
            zero=zero,
            units=units,
        )

        duration.additional_properties = d
        return duration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.big_query_authentication_mode import BigQueryAuthenticationMode
from ..models.big_query_jobs_create_project import BigQueryJobsCreateProject
from ..types import UNSET, Unset

T = TypeVar("T", bound="BigQueryParametersSpec")


@_attrs_define
class BigQueryParametersSpec:
    """
    Attributes:
        source_project_id (Union[Unset, str]): Source GCP project ID. This is the project that has datasets that will be
            imported.
        jobs_create_project (Union[Unset, BigQueryJobsCreateProject]):
        billing_project_id (Union[Unset, str]): Billing GCP project ID. This is the project used as the default GCP
            project. The calling user must have a bigquery.jobs.create permission in this project.
        authentication_mode (Union[Unset, BigQueryAuthenticationMode]):
        json_key_content (Union[Unset, str]): JSON key content. Use an environment variable that contains the content of
            the key as ${KEY_ENV} or a name of a secret in the GCP Secret Manager: ${sm://key-secret-name}. Requires the
            authentication-mode: json_key_content.
        json_key_path (Union[Unset, str]): A path to the JSON key file. Requires the authentication-mode: json_key_path.
        quota_project_id (Union[Unset, str]): Quota GCP project ID.
    """

    source_project_id: Union[Unset, str] = UNSET
    jobs_create_project: Union[Unset, BigQueryJobsCreateProject] = UNSET
    billing_project_id: Union[Unset, str] = UNSET
    authentication_mode: Union[Unset, BigQueryAuthenticationMode] = UNSET
    json_key_content: Union[Unset, str] = UNSET
    json_key_path: Union[Unset, str] = UNSET
    quota_project_id: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        source_project_id = self.source_project_id
        jobs_create_project: Union[Unset, str] = UNSET
        if not isinstance(self.jobs_create_project, Unset):
            jobs_create_project = self.jobs_create_project.value

        billing_project_id = self.billing_project_id
        authentication_mode: Union[Unset, str] = UNSET
        if not isinstance(self.authentication_mode, Unset):
            authentication_mode = self.authentication_mode.value

        json_key_content = self.json_key_content
        json_key_path = self.json_key_path
        quota_project_id = self.quota_project_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if source_project_id is not UNSET:
            field_dict["source_project_id"] = source_project_id
        if jobs_create_project is not UNSET:
            field_dict["jobs_create_project"] = jobs_create_project
        if billing_project_id is not UNSET:
            field_dict["billing_project_id"] = billing_project_id
        if authentication_mode is not UNSET:
            field_dict["authentication_mode"] = authentication_mode
        if json_key_content is not UNSET:
            field_dict["json_key_content"] = json_key_content
        if json_key_path is not UNSET:
            field_dict["json_key_path"] = json_key_path
        if quota_project_id is not UNSET:
            field_dict["quota_project_id"] = quota_project_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        source_project_id = d.pop("source_project_id", UNSET)

        _jobs_create_project = d.pop("jobs_create_project", UNSET)
        jobs_create_project: Union[Unset, BigQueryJobsCreateProject]
        if isinstance(_jobs_create_project, Unset):
            jobs_create_project = UNSET
        else:
            jobs_create_project = BigQueryJobsCreateProject(_jobs_create_project)

        billing_project_id = d.pop("billing_project_id", UNSET)

        _authentication_mode = d.pop("authentication_mode", UNSET)
        authentication_mode: Union[Unset, BigQueryAuthenticationMode]
        if isinstance(_authentication_mode, Unset):
            authentication_mode = UNSET
        else:
            authentication_mode = BigQueryAuthenticationMode(_authentication_mode)

        json_key_content = d.pop("json_key_content", UNSET)

        json_key_path = d.pop("json_key_path", UNSET)

        quota_project_id = d.pop("quota_project_id", UNSET)

        big_query_parameters_spec = cls(
            source_project_id=source_project_id,
            jobs_create_project=jobs_create_project,
            billing_project_id=billing_project_id,
            authentication_mode=authentication_mode,
            json_key_content=json_key_content,
            json_key_path=json_key_path,
            quota_project_id=quota_project_id,
        )

        big_query_parameters_spec.additional_properties = d
        return big_query_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.run_checks_target import RunChecksTarget
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.check_search_filters import CheckSearchFilters
    from ..models.run_checks_result import RunChecksResult
    from ..models.time_window_filter_parameters import TimeWindowFilterParameters


T = TypeVar("T", bound="RunChecksParameters")


@_attrs_define
class RunChecksParameters:
    """Run checks configuration, specifies the target checks that should be executed and an optional time window.

    Attributes:
        check_search_filters (Union[Unset, CheckSearchFilters]): Target data quality checks filter, identifies which
            checks on which tables and columns should be executed.
        time_window_filter (Union[Unset, TimeWindowFilterParameters]): Time window configuration for partitioned checks
            (the number of recent days or months to analyze in an incremental mode) or an absolute time range to analyze.
        collect_error_samples (Union[Unset, bool]): Set the value to true to collect error samples for failed data
            quality checks. Set the value to false to disable error sampling collection despite any other settings on the
            table or check level.
        execution_target (Union[Unset, RunChecksTarget]):
        dummy_execution (Union[Unset, bool]): Set the value to true when the data quality checks should be executed in a
            dummy mode (without running checks on the target systems and storing the results). Only the jinja2 sensors will
            be rendered.
        run_checks_result (Union[Unset, RunChecksResult]): Returns the result (highest data quality check severity and
            the finished checks count) for the checks that were recently executed.
    """

    check_search_filters: Union[Unset, "CheckSearchFilters"] = UNSET
    time_window_filter: Union[Unset, "TimeWindowFilterParameters"] = UNSET
    collect_error_samples: Union[Unset, bool] = UNSET
    execution_target: Union[Unset, RunChecksTarget] = UNSET
    dummy_execution: Union[Unset, bool] = UNSET
    run_checks_result: Union[Unset, "RunChecksResult"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        check_search_filters: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.check_search_filters, Unset):
            check_search_filters = self.check_search_filters.to_dict()

        time_window_filter: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.time_window_filter, Unset):
            time_window_filter = self.time_window_filter.to_dict()

        collect_error_samples = self.collect_error_samples
        execution_target: Union[Unset, str] = UNSET
        if not isinstance(self.execution_target, Unset):
            execution_target = self.execution_target.value

        dummy_execution = self.dummy_execution
        run_checks_result: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.run_checks_result, Unset):
            run_checks_result = self.run_checks_result.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if check_search_filters is not UNSET:
            field_dict["check_search_filters"] = check_search_filters
        if time_window_filter is not UNSET:
            field_dict["time_window_filter"] = time_window_filter
        if collect_error_samples is not UNSET:
            field_dict["collect_error_samples"] = collect_error_samples
        if execution_target is not UNSET:
            field_dict["execution_target"] = execution_target
        if dummy_execution is not UNSET:
            field_dict["dummy_execution"] = dummy_execution
        if run_checks_result is not UNSET:
            field_dict["run_checks_result"] = run_checks_result

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.check_search_filters import CheckSearchFilters
        from ..models.run_checks_result import RunChecksResult
        from ..models.time_window_filter_parameters import TimeWindowFilterParameters

        d = src_dict.copy()
        _check_search_filters = d.pop("check_search_filters", UNSET)
        check_search_filters: Union[Unset, CheckSearchFilters]
        if isinstance(_check_search_filters, Unset):
            check_search_filters = UNSET
        else:
            check_search_filters = CheckSearchFilters.from_dict(_check_search_filters)

        _time_window_filter = d.pop("time_window_filter", UNSET)
        time_window_filter: Union[Unset, TimeWindowFilterParameters]
        if isinstance(_time_window_filter, Unset):
            time_window_filter = UNSET
        else:
            time_window_filter = TimeWindowFilterParameters.from_dict(
                _time_window_filter
            )

        collect_error_samples = d.pop("collect_error_samples", UNSET)

        _execution_target = d.pop("execution_target", UNSET)
        execution_target: Union[Unset, RunChecksTarget]
        if isinstance(_execution_target, Unset):
            execution_target = UNSET
        else:
            execution_target = RunChecksTarget(_execution_target)

        dummy_execution = d.pop("dummy_execution", UNSET)

        _run_checks_result = d.pop("run_checks_result", UNSET)
        run_checks_result: Union[Unset, RunChecksResult]
        if isinstance(_run_checks_result, Unset):
            run_checks_result = UNSET
        else:
            run_checks_result = RunChecksResult.from_dict(_run_checks_result)

        run_checks_parameters = cls(
            check_search_filters=check_search_filters,
            time_window_filter=time_window_filter,
            collect_error_samples=collect_error_samples,
            execution_target=execution_target,
            dummy_execution=dummy_execution,
            run_checks_result=run_checks_result,
        )

        run_checks_parameters.additional_properties = d
        return run_checks_parameters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
